// Copyright 2015, VIXL authors
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


// ---------------------------------------------------------------------
// This file is auto generated using tools/generate_simulator_traces.py.
//
// PLEASE DO NOT EDIT.
// ---------------------------------------------------------------------

#ifndef VIXL_ASSEMBLER_COND_RD_RN_OPERAND_RM_SHIFT_AMOUNT_1TO32_EOR_A32_H_
#define VIXL_ASSEMBLER_COND_RD_RN_OPERAND_RM_SHIFT_AMOUNT_1TO32_EOR_A32_H_

const byte kInstruction_eor_eq_r13_r6_r7_ASR_5[] = {
  0xc7, 0xd2, 0x26, 0x00 // eor eq r13 r6 r7 ASR 5
};
const byte kInstruction_eor_mi_r8_r11_r8_ASR_32[] = {
  0x48, 0x80, 0x2b, 0x40 // eor mi r8 r11 r8 ASR 32
};
const byte kInstruction_eor_hi_r2_r3_r10_ASR_18[] = {
  0x4a, 0x29, 0x23, 0x80 // eor hi r2 r3 r10 ASR 18
};
const byte kInstruction_eor_ls_r13_r8_r14_LSR_32[] = {
  0x2e, 0xd0, 0x28, 0x90 // eor ls r13 r8 r14 LSR 32
};
const byte kInstruction_eor_cc_r8_r9_r2_ASR_3[] = {
  0xc2, 0x81, 0x29, 0x30 // eor cc r8 r9 r2 ASR 3
};
const byte kInstruction_eor_ls_r14_r2_r5_LSR_2[] = {
  0x25, 0xe1, 0x22, 0x90 // eor ls r14 r2 r5 LSR 2
};
const byte kInstruction_eor_pl_r8_r6_r1_ASR_31[] = {
  0xc1, 0x8f, 0x26, 0x50 // eor pl r8 r6 r1 ASR 31
};
const byte kInstruction_eor_le_r2_r0_r14_LSR_3[] = {
  0xae, 0x21, 0x20, 0xd0 // eor le r2 r0 r14 LSR 3
};
const byte kInstruction_eor_ne_r2_r0_r13_LSR_15[] = {
  0xad, 0x27, 0x20, 0x10 // eor ne r2 r0 r13 LSR 15
};
const byte kInstruction_eor_ge_r9_r12_r3_LSR_8[] = {
  0x23, 0x94, 0x2c, 0xa0 // eor ge r9 r12 r3 LSR 8
};
const byte kInstruction_eor_pl_r13_r8_r1_ASR_7[] = {
  0xc1, 0xd3, 0x28, 0x50 // eor pl r13 r8 r1 ASR 7
};
const byte kInstruction_eor_cs_r10_r13_r4_LSR_5[] = {
  0xa4, 0xa2, 0x2d, 0x20 // eor cs r10 r13 r4 LSR 5
};
const byte kInstruction_eor_pl_r13_r8_r11_ASR_17[] = {
  0xcb, 0xd8, 0x28, 0x50 // eor pl r13 r8 r11 ASR 17
};
const byte kInstruction_eor_cs_r8_r7_r3_LSR_9[] = {
  0xa3, 0x84, 0x27, 0x20 // eor cs r8 r7 r3 LSR 9
};
const byte kInstruction_eor_vc_r11_r2_r7_LSR_30[] = {
  0x27, 0xbf, 0x22, 0x70 // eor vc r11 r2 r7 LSR 30
};
const byte kInstruction_eor_ge_r6_r14_r7_LSR_19[] = {
  0xa7, 0x69, 0x2e, 0xa0 // eor ge r6 r14 r7 LSR 19
};
const byte kInstruction_eor_cc_r11_r3_r0_LSR_20[] = {
  0x20, 0xba, 0x23, 0x30 // eor cc r11 r3 r0 LSR 20
};
const byte kInstruction_eor_lt_r10_r9_r7_ASR_25[] = {
  0xc7, 0xac, 0x29, 0xb0 // eor lt r10 r9 r7 ASR 25
};
const byte kInstruction_eor_ne_r8_r0_r12_LSR_30[] = {
  0x2c, 0x8f, 0x20, 0x10 // eor ne r8 r0 r12 LSR 30
};
const byte kInstruction_eor_vc_r1_r4_r13_ASR_32[] = {
  0x4d, 0x10, 0x24, 0x70 // eor vc r1 r4 r13 ASR 32
};
const byte kInstruction_eor_al_r8_r14_r8_LSR_14[] = {
  0x28, 0x87, 0x2e, 0xe0 // eor al r8 r14 r8 LSR 14
};
const byte kInstruction_eor_pl_r2_r12_r7_ASR_2[] = {
  0x47, 0x21, 0x2c, 0x50 // eor pl r2 r12 r7 ASR 2
};
const byte kInstruction_eor_pl_r11_r1_r0_LSR_14[] = {
  0x20, 0xb7, 0x21, 0x50 // eor pl r11 r1 r0 LSR 14
};
const byte kInstruction_eor_gt_r5_r11_r9_ASR_24[] = {
  0x49, 0x5c, 0x2b, 0xc0 // eor gt r5 r11 r9 ASR 24
};
const byte kInstruction_eor_eq_r8_r9_r12_ASR_6[] = {
  0x4c, 0x83, 0x29, 0x00 // eor eq r8 r9 r12 ASR 6
};
const byte kInstruction_eor_cs_r10_r9_r12_LSR_30[] = {
  0x2c, 0xaf, 0x29, 0x20 // eor cs r10 r9 r12 LSR 30
};
const byte kInstruction_eor_lt_r7_r11_r2_ASR_21[] = {
  0xc2, 0x7a, 0x2b, 0xb0 // eor lt r7 r11 r2 ASR 21
};
const byte kInstruction_eor_eq_r14_r3_r11_LSR_10[] = {
  0x2b, 0xe5, 0x23, 0x00 // eor eq r14 r3 r11 LSR 10
};
const byte kInstruction_eor_vs_r4_r11_r5_ASR_7[] = {
  0xc5, 0x43, 0x2b, 0x60 // eor vs r4 r11 r5 ASR 7
};
const byte kInstruction_eor_le_r7_r14_r12_ASR_3[] = {
  0xcc, 0x71, 0x2e, 0xd0 // eor le r7 r14 r12 ASR 3
};
const byte kInstruction_eor_ne_r7_r4_r0_ASR_17[] = {
  0xc0, 0x78, 0x24, 0x10 // eor ne r7 r4 r0 ASR 17
};
const byte kInstruction_eor_hi_r5_r11_r3_ASR_4[] = {
  0x43, 0x52, 0x2b, 0x80 // eor hi r5 r11 r3 ASR 4
};
const byte kInstruction_eor_cs_r8_r7_r9_LSR_24[] = {
  0x29, 0x8c, 0x27, 0x20 // eor cs r8 r7 r9 LSR 24
};
const byte kInstruction_eor_vc_r3_r9_r13_LSR_7[] = {
  0xad, 0x33, 0x29, 0x70 // eor vc r3 r9 r13 LSR 7
};
const byte kInstruction_eor_lt_r6_r14_r3_LSR_2[] = {
  0x23, 0x61, 0x2e, 0xb0 // eor lt r6 r14 r3 LSR 2
};
const byte kInstruction_eor_lt_r10_r14_r2_LSR_29[] = {
  0xa2, 0xae, 0x2e, 0xb0 // eor lt r10 r14 r2 LSR 29
};
const byte kInstruction_eor_mi_r8_r12_r0_ASR_30[] = {
  0x40, 0x8f, 0x2c, 0x40 // eor mi r8 r12 r0 ASR 30
};
const byte kInstruction_eor_ls_r9_r0_r5_LSR_25[] = {
  0xa5, 0x9c, 0x20, 0x90 // eor ls r9 r0 r5 LSR 25
};
const byte kInstruction_eor_ls_r10_r12_r5_ASR_21[] = {
  0xc5, 0xaa, 0x2c, 0x90 // eor ls r10 r12 r5 ASR 21
};
const byte kInstruction_eor_vs_r9_r10_r0_LSR_8[] = {
  0x20, 0x94, 0x2a, 0x60 // eor vs r9 r10 r0 LSR 8
};
const byte kInstruction_eor_mi_r13_r9_r9_LSR_32[] = {
  0x29, 0xd0, 0x29, 0x40 // eor mi r13 r9 r9 LSR 32
};
const byte kInstruction_eor_mi_r10_r14_r4_ASR_5[] = {
  0xc4, 0xa2, 0x2e, 0x40 // eor mi r10 r14 r4 ASR 5
};
const byte kInstruction_eor_ls_r12_r2_r12_LSR_7[] = {
  0xac, 0xc3, 0x22, 0x90 // eor ls r12 r2 r12 LSR 7
};
const byte kInstruction_eor_ne_r5_r5_r11_LSR_20[] = {
  0x2b, 0x5a, 0x25, 0x10 // eor ne r5 r5 r11 LSR 20
};
const byte kInstruction_eor_vc_r5_r2_r13_ASR_15[] = {
  0xcd, 0x57, 0x22, 0x70 // eor vc r5 r2 r13 ASR 15
};
const byte kInstruction_eor_cc_r8_r13_r0_LSR_2[] = {
  0x20, 0x81, 0x2d, 0x30 // eor cc r8 r13 r0 LSR 2
};
const byte kInstruction_eor_hi_r5_r5_r12_LSR_9[] = {
  0xac, 0x54, 0x25, 0x80 // eor hi r5 r5 r12 LSR 9
};
const byte kInstruction_eor_cs_r9_r10_r5_ASR_29[] = {
  0xc5, 0x9e, 0x2a, 0x20 // eor cs r9 r10 r5 ASR 29
};
const byte kInstruction_eor_le_r14_r1_r2_ASR_10[] = {
  0x42, 0xe5, 0x21, 0xd0 // eor le r14 r1 r2 ASR 10
};
const byte kInstruction_eor_mi_r1_r11_r5_LSR_23[] = {
  0xa5, 0x1b, 0x2b, 0x40 // eor mi r1 r11 r5 LSR 23
};
const byte kInstruction_eor_vc_r3_r0_r12_LSR_9[] = {
  0xac, 0x34, 0x20, 0x70 // eor vc r3 r0 r12 LSR 9
};
const byte kInstruction_eor_cs_r2_r4_r11_LSR_14[] = {
  0x2b, 0x27, 0x24, 0x20 // eor cs r2 r4 r11 LSR 14
};
const byte kInstruction_eor_gt_r8_r13_r2_ASR_29[] = {
  0xc2, 0x8e, 0x2d, 0xc0 // eor gt r8 r13 r2 ASR 29
};
const byte kInstruction_eor_vc_r1_r8_r13_ASR_9[] = {
  0xcd, 0x14, 0x28, 0x70 // eor vc r1 r8 r13 ASR 9
};
const byte kInstruction_eor_vs_r3_r10_r6_LSR_29[] = {
  0xa6, 0x3e, 0x2a, 0x60 // eor vs r3 r10 r6 LSR 29
};
const byte kInstruction_eor_ge_r1_r3_r6_LSR_6[] = {
  0x26, 0x13, 0x23, 0xa0 // eor ge r1 r3 r6 LSR 6
};
const byte kInstruction_eor_cs_r5_r1_r9_ASR_4[] = {
  0x49, 0x52, 0x21, 0x20 // eor cs r5 r1 r9 ASR 4
};
const byte kInstruction_eor_le_r3_r6_r14_ASR_22[] = {
  0x4e, 0x3b, 0x26, 0xd0 // eor le r3 r6 r14 ASR 22
};
const byte kInstruction_eor_le_r4_r4_r9_LSR_15[] = {
  0xa9, 0x47, 0x24, 0xd0 // eor le r4 r4 r9 LSR 15
};
const byte kInstruction_eor_le_r13_r3_r1_LSR_25[] = {
  0xa1, 0xdc, 0x23, 0xd0 // eor le r13 r3 r1 LSR 25
};
const byte kInstruction_eor_cc_r8_r14_r8_ASR_5[] = {
  0xc8, 0x82, 0x2e, 0x30 // eor cc r8 r14 r8 ASR 5
};
const byte kInstruction_eor_ge_r6_r12_r0_ASR_14[] = {
  0x40, 0x67, 0x2c, 0xa0 // eor ge r6 r12 r0 ASR 14
};
const byte kInstruction_eor_gt_r3_r6_r10_LSR_15[] = {
  0xaa, 0x37, 0x26, 0xc0 // eor gt r3 r6 r10 LSR 15
};
const byte kInstruction_eor_cs_r0_r5_r6_LSR_29[] = {
  0xa6, 0x0e, 0x25, 0x20 // eor cs r0 r5 r6 LSR 29
};
const byte kInstruction_eor_pl_r6_r4_r3_LSR_13[] = {
  0xa3, 0x66, 0x24, 0x50 // eor pl r6 r4 r3 LSR 13
};
const byte kInstruction_eor_pl_r8_r12_r6_LSR_5[] = {
  0xa6, 0x82, 0x2c, 0x50 // eor pl r8 r12 r6 LSR 5
};
const byte kInstruction_eor_vc_r13_r7_r0_LSR_18[] = {
  0x20, 0xd9, 0x27, 0x70 // eor vc r13 r7 r0 LSR 18
};
const byte kInstruction_eor_ne_r0_r12_r8_ASR_1[] = {
  0xc8, 0x00, 0x2c, 0x10 // eor ne r0 r12 r8 ASR 1
};
const byte kInstruction_eor_ls_r8_r2_r10_ASR_14[] = {
  0x4a, 0x87, 0x22, 0x90 // eor ls r8 r2 r10 ASR 14
};
const byte kInstruction_eor_al_r5_r3_r9_ASR_2[] = {
  0x49, 0x51, 0x23, 0xe0 // eor al r5 r3 r9 ASR 2
};
const byte kInstruction_eor_vc_r1_r14_r13_LSR_4[] = {
  0x2d, 0x12, 0x2e, 0x70 // eor vc r1 r14 r13 LSR 4
};
const byte kInstruction_eor_vc_r0_r10_r4_LSR_30[] = {
  0x24, 0x0f, 0x2a, 0x70 // eor vc r0 r10 r4 LSR 30
};
const byte kInstruction_eor_al_r3_r0_r11_ASR_14[] = {
  0x4b, 0x37, 0x20, 0xe0 // eor al r3 r0 r11 ASR 14
};
const byte kInstruction_eor_vs_r3_r11_r10_ASR_23[] = {
  0xca, 0x3b, 0x2b, 0x60 // eor vs r3 r11 r10 ASR 23
};
const byte kInstruction_eor_ls_r0_r9_r0_ASR_8[] = {
  0x40, 0x04, 0x29, 0x90 // eor ls r0 r9 r0 ASR 8
};
const byte kInstruction_eor_le_r2_r8_r10_LSR_5[] = {
  0xaa, 0x22, 0x28, 0xd0 // eor le r2 r8 r10 LSR 5
};
const byte kInstruction_eor_cs_r0_r5_r0_LSR_31[] = {
  0xa0, 0x0f, 0x25, 0x20 // eor cs r0 r5 r0 LSR 31
};
const byte kInstruction_eor_cc_r1_r10_r13_LSR_27[] = {
  0xad, 0x1d, 0x2a, 0x30 // eor cc r1 r10 r13 LSR 27
};
const byte kInstruction_eor_ge_r11_r13_r12_ASR_17[] = {
  0xcc, 0xb8, 0x2d, 0xa0 // eor ge r11 r13 r12 ASR 17
};
const byte kInstruction_eor_eq_r2_r9_r4_LSR_12[] = {
  0x24, 0x26, 0x29, 0x00 // eor eq r2 r9 r4 LSR 12
};
const byte kInstruction_eor_ge_r4_r14_r0_ASR_13[] = {
  0xc0, 0x46, 0x2e, 0xa0 // eor ge r4 r14 r0 ASR 13
};
const byte kInstruction_eor_vc_r1_r6_r0_ASR_16[] = {
  0x40, 0x18, 0x26, 0x70 // eor vc r1 r6 r0 ASR 16
};
const byte kInstruction_eor_hi_r7_r9_r12_LSR_11[] = {
  0xac, 0x75, 0x29, 0x80 // eor hi r7 r9 r12 LSR 11
};
const byte kInstruction_eor_eq_r14_r11_r12_LSR_29[] = {
  0xac, 0xee, 0x2b, 0x00 // eor eq r14 r11 r12 LSR 29
};
const byte kInstruction_eor_ge_r14_r13_r4_ASR_23[] = {
  0xc4, 0xeb, 0x2d, 0xa0 // eor ge r14 r13 r4 ASR 23
};
const byte kInstruction_eor_pl_r8_r0_r14_ASR_25[] = {
  0xce, 0x8c, 0x20, 0x50 // eor pl r8 r0 r14 ASR 25
};
const byte kInstruction_eor_ne_r7_r13_r12_LSR_14[] = {
  0x2c, 0x77, 0x2d, 0x10 // eor ne r7 r13 r12 LSR 14
};
const byte kInstruction_eor_vs_r13_r4_r7_ASR_10[] = {
  0x47, 0xd5, 0x24, 0x60 // eor vs r13 r4 r7 ASR 10
};
const byte kInstruction_eor_mi_r3_r14_r9_ASR_15[] = {
  0xc9, 0x37, 0x2e, 0x40 // eor mi r3 r14 r9 ASR 15
};
const byte kInstruction_eor_cs_r14_r9_r14_ASR_25[] = {
  0xce, 0xec, 0x29, 0x20 // eor cs r14 r9 r14 ASR 25
};
const byte kInstruction_eor_cc_r11_r7_r4_LSR_4[] = {
  0x24, 0xb2, 0x27, 0x30 // eor cc r11 r7 r4 LSR 4
};
const byte kInstruction_eor_cc_r11_r7_r2_ASR_1[] = {
  0xc2, 0xb0, 0x27, 0x30 // eor cc r11 r7 r2 ASR 1
};
const byte kInstruction_eor_al_r0_r5_r5_LSR_11[] = {
  0xa5, 0x05, 0x25, 0xe0 // eor al r0 r5 r5 LSR 11
};
const byte kInstruction_eor_eq_r3_r5_r13_LSR_3[] = {
  0xad, 0x31, 0x25, 0x00 // eor eq r3 r5 r13 LSR 3
};
const byte kInstruction_eor_ge_r11_r1_r1_ASR_24[] = {
  0x41, 0xbc, 0x21, 0xa0 // eor ge r11 r1 r1 ASR 24
};
const byte kInstruction_eor_lt_r13_r12_r12_LSR_9[] = {
  0xac, 0xd4, 0x2c, 0xb0 // eor lt r13 r12 r12 LSR 9
};
const byte kInstruction_eor_cs_r13_r1_r14_LSR_26[] = {
  0x2e, 0xdd, 0x21, 0x20 // eor cs r13 r1 r14 LSR 26
};
const byte kInstruction_eor_ge_r10_r4_r4_LSR_31[] = {
  0xa4, 0xaf, 0x24, 0xa0 // eor ge r10 r4 r4 LSR 31
};
const byte kInstruction_eor_pl_r7_r7_r5_ASR_5[] = {
  0xc5, 0x72, 0x27, 0x50 // eor pl r7 r7 r5 ASR 5
};
const byte kInstruction_eor_eq_r2_r13_r10_ASR_26[] = {
  0x4a, 0x2d, 0x2d, 0x00 // eor eq r2 r13 r10 ASR 26
};
const byte kInstruction_eor_ne_r5_r8_r13_LSR_23[] = {
  0xad, 0x5b, 0x28, 0x10 // eor ne r5 r8 r13 LSR 23
};
const byte kInstruction_eor_al_r0_r5_r12_LSR_1[] = {
  0xac, 0x00, 0x25, 0xe0 // eor al r0 r5 r12 LSR 1
};
const byte kInstruction_eor_al_r10_r11_r4_ASR_23[] = {
  0xc4, 0xab, 0x2b, 0xe0 // eor al r10 r11 r4 ASR 23
};
const byte kInstruction_eor_al_r0_r11_r10_LSR_1[] = {
  0xaa, 0x00, 0x2b, 0xe0 // eor al r0 r11 r10 LSR 1
};
const byte kInstruction_eor_eq_r9_r9_r2_LSR_18[] = {
  0x22, 0x99, 0x29, 0x00 // eor eq r9 r9 r2 LSR 18
};
const byte kInstruction_eor_mi_r2_r9_r8_ASR_25[] = {
  0xc8, 0x2c, 0x29, 0x40 // eor mi r2 r9 r8 ASR 25
};
const byte kInstruction_eor_vc_r6_r7_r1_LSR_3[] = {
  0xa1, 0x61, 0x27, 0x70 // eor vc r6 r7 r1 LSR 3
};
const byte kInstruction_eor_pl_r6_r10_r0_ASR_29[] = {
  0xc0, 0x6e, 0x2a, 0x50 // eor pl r6 r10 r0 ASR 29
};
const byte kInstruction_eor_gt_r9_r5_r5_ASR_10[] = {
  0x45, 0x95, 0x25, 0xc0 // eor gt r9 r5 r5 ASR 10
};
const byte kInstruction_eor_mi_r1_r0_r3_LSR_28[] = {
  0x23, 0x1e, 0x20, 0x40 // eor mi r1 r0 r3 LSR 28
};
const byte kInstruction_eor_ne_r10_r11_r9_LSR_8[] = {
  0x29, 0xa4, 0x2b, 0x10 // eor ne r10 r11 r9 LSR 8
};
const byte kInstruction_eor_ls_r1_r9_r3_ASR_29[] = {
  0xc3, 0x1e, 0x29, 0x90 // eor ls r1 r9 r3 ASR 29
};
const byte kInstruction_eor_eq_r13_r10_r13_LSR_9[] = {
  0xad, 0xd4, 0x2a, 0x00 // eor eq r13 r10 r13 LSR 9
};
const byte kInstruction_eor_mi_r13_r0_r3_ASR_20[] = {
  0x43, 0xda, 0x20, 0x40 // eor mi r13 r0 r3 ASR 20
};
const byte kInstruction_eor_eq_r14_r13_r12_ASR_18[] = {
  0x4c, 0xe9, 0x2d, 0x00 // eor eq r14 r13 r12 ASR 18
};
const byte kInstruction_eor_mi_r10_r7_r6_ASR_2[] = {
  0x46, 0xa1, 0x27, 0x40 // eor mi r10 r7 r6 ASR 2
};
const byte kInstruction_eor_hi_r0_r1_r2_LSR_32[] = {
  0x22, 0x00, 0x21, 0x80 // eor hi r0 r1 r2 LSR 32
};
const byte kInstruction_eor_pl_r10_r2_r8_LSR_14[] = {
  0x28, 0xa7, 0x22, 0x50 // eor pl r10 r2 r8 LSR 14
};
const byte kInstruction_eor_le_r12_r6_r2_ASR_8[] = {
  0x42, 0xc4, 0x26, 0xd0 // eor le r12 r6 r2 ASR 8
};
const byte kInstruction_eor_gt_r4_r0_r4_ASR_12[] = {
  0x44, 0x46, 0x20, 0xc0 // eor gt r4 r0 r4 ASR 12
};
const byte kInstruction_eor_eq_r9_r0_r10_LSR_15[] = {
  0xaa, 0x97, 0x20, 0x00 // eor eq r9 r0 r10 LSR 15
};
const byte kInstruction_eor_ge_r7_r1_r8_ASR_8[] = {
  0x48, 0x74, 0x21, 0xa0 // eor ge r7 r1 r8 ASR 8
};
const byte kInstruction_eor_al_r1_r1_r12_ASR_7[] = {
  0xcc, 0x13, 0x21, 0xe0 // eor al r1 r1 r12 ASR 7
};
const byte kInstruction_eor_lt_r13_r1_r2_LSR_11[] = {
  0xa2, 0xd5, 0x21, 0xb0 // eor lt r13 r1 r2 LSR 11
};
const byte kInstruction_eor_cc_r2_r5_r3_ASR_3[] = {
  0xc3, 0x21, 0x25, 0x30 // eor cc r2 r5 r3 ASR 3
};
const byte kInstruction_eor_ne_r8_r2_r9_LSR_14[] = {
  0x29, 0x87, 0x22, 0x10 // eor ne r8 r2 r9 LSR 14
};
const byte kInstruction_eor_eq_r11_r8_r1_LSR_3[] = {
  0xa1, 0xb1, 0x28, 0x00 // eor eq r11 r8 r1 LSR 3
};
const byte kInstruction_eor_al_r3_r14_r11_LSR_14[] = {
  0x2b, 0x37, 0x2e, 0xe0 // eor al r3 r14 r11 LSR 14
};
const byte kInstruction_eor_pl_r1_r2_r7_LSR_31[] = {
  0xa7, 0x1f, 0x22, 0x50 // eor pl r1 r2 r7 LSR 31
};
const byte kInstruction_eor_eq_r14_r2_r5_LSR_20[] = {
  0x25, 0xea, 0x22, 0x00 // eor eq r14 r2 r5 LSR 20
};
const byte kInstruction_eor_hi_r7_r13_r3_LSR_21[] = {
  0xa3, 0x7a, 0x2d, 0x80 // eor hi r7 r13 r3 LSR 21
};
const byte kInstruction_eor_gt_r14_r7_r11_LSR_16[] = {
  0x2b, 0xe8, 0x27, 0xc0 // eor gt r14 r7 r11 LSR 16
};
const byte kInstruction_eor_ls_r0_r5_r14_ASR_25[] = {
  0xce, 0x0c, 0x25, 0x90 // eor ls r0 r5 r14 ASR 25
};
const byte kInstruction_eor_cc_r0_r7_r8_LSR_4[] = {
  0x28, 0x02, 0x27, 0x30 // eor cc r0 r7 r8 LSR 4
};
const byte kInstruction_eor_hi_r3_r5_r9_ASR_9[] = {
  0xc9, 0x34, 0x25, 0x80 // eor hi r3 r5 r9 ASR 9
};
const byte kInstruction_eor_hi_r10_r5_r5_ASR_15[] = {
  0xc5, 0xa7, 0x25, 0x80 // eor hi r10 r5 r5 ASR 15
};
const byte kInstruction_eor_le_r7_r14_r0_LSR_19[] = {
  0xa0, 0x79, 0x2e, 0xd0 // eor le r7 r14 r0 LSR 19
};
const byte kInstruction_eor_gt_r10_r1_r2_LSR_16[] = {
  0x22, 0xa8, 0x21, 0xc0 // eor gt r10 r1 r2 LSR 16
};
const byte kInstruction_eor_ls_r4_r14_r10_LSR_21[] = {
  0xaa, 0x4a, 0x2e, 0x90 // eor ls r4 r14 r10 LSR 21
};
const byte kInstruction_eor_mi_r12_r14_r3_LSR_11[] = {
  0xa3, 0xc5, 0x2e, 0x40 // eor mi r12 r14 r3 LSR 11
};
const byte kInstruction_eor_al_r7_r9_r4_LSR_12[] = {
  0x24, 0x76, 0x29, 0xe0 // eor al r7 r9 r4 LSR 12
};
const byte kInstruction_eor_cc_r0_r10_r1_ASR_20[] = {
  0x41, 0x0a, 0x2a, 0x30 // eor cc r0 r10 r1 ASR 20
};
const byte kInstruction_eor_mi_r0_r2_r11_LSR_31[] = {
  0xab, 0x0f, 0x22, 0x40 // eor mi r0 r2 r11 LSR 31
};
const byte kInstruction_eor_cs_r7_r9_r6_ASR_22[] = {
  0x46, 0x7b, 0x29, 0x20 // eor cs r7 r9 r6 ASR 22
};
const byte kInstruction_eor_gt_r9_r6_r13_LSR_25[] = {
  0xad, 0x9c, 0x26, 0xc0 // eor gt r9 r6 r13 LSR 25
};
const byte kInstruction_eor_cc_r1_r2_r8_ASR_16[] = {
  0x48, 0x18, 0x22, 0x30 // eor cc r1 r2 r8 ASR 16
};
const byte kInstruction_eor_ne_r6_r4_r14_ASR_12[] = {
  0x4e, 0x66, 0x24, 0x10 // eor ne r6 r4 r14 ASR 12
};
const byte kInstruction_eor_al_r7_r2_r14_ASR_11[] = {
  0xce, 0x75, 0x22, 0xe0 // eor al r7 r2 r14 ASR 11
};
const byte kInstruction_eor_gt_r10_r14_r13_LSR_22[] = {
  0x2d, 0xab, 0x2e, 0xc0 // eor gt r10 r14 r13 LSR 22
};
const byte kInstruction_eor_lt_r0_r8_r6_LSR_25[] = {
  0xa6, 0x0c, 0x28, 0xb0 // eor lt r0 r8 r6 LSR 25
};
const byte kInstruction_eor_ne_r12_r5_r6_ASR_20[] = {
  0x46, 0xca, 0x25, 0x10 // eor ne r12 r5 r6 ASR 20
};
const byte kInstruction_eor_pl_r12_r6_r7_ASR_27[] = {
  0xc7, 0xcd, 0x26, 0x50 // eor pl r12 r6 r7 ASR 27
};
const byte kInstruction_eor_gt_r5_r8_r7_ASR_19[] = {
  0xc7, 0x59, 0x28, 0xc0 // eor gt r5 r8 r7 ASR 19
};
const byte kInstruction_eor_le_r12_r1_r4_LSR_22[] = {
  0x24, 0xcb, 0x21, 0xd0 // eor le r12 r1 r4 LSR 22
};
const byte kInstruction_eor_le_r9_r8_r11_LSR_17[] = {
  0xab, 0x98, 0x28, 0xd0 // eor le r9 r8 r11 LSR 17
};
const byte kInstruction_eor_gt_r5_r2_r3_ASR_30[] = {
  0x43, 0x5f, 0x22, 0xc0 // eor gt r5 r2 r3 ASR 30
};
const byte kInstruction_eor_ge_r8_r7_r7_ASR_31[] = {
  0xc7, 0x8f, 0x27, 0xa0 // eor ge r8 r7 r7 ASR 31
};
const byte kInstruction_eor_lt_r14_r8_r11_ASR_23[] = {
  0xcb, 0xeb, 0x28, 0xb0 // eor lt r14 r8 r11 ASR 23
};
const byte kInstruction_eor_cc_r0_r11_r6_LSR_1[] = {
  0xa6, 0x00, 0x2b, 0x30 // eor cc r0 r11 r6 LSR 1
};
const byte kInstruction_eor_pl_r0_r6_r14_LSR_2[] = {
  0x2e, 0x01, 0x26, 0x50 // eor pl r0 r6 r14 LSR 2
};
const byte kInstruction_eor_lt_r4_r2_r1_ASR_16[] = {
  0x41, 0x48, 0x22, 0xb0 // eor lt r4 r2 r1 ASR 16
};
const byte kInstruction_eor_pl_r14_r2_r14_ASR_19[] = {
  0xce, 0xe9, 0x22, 0x50 // eor pl r14 r2 r14 ASR 19
};
const byte kInstruction_eor_cs_r13_r5_r9_LSR_32[] = {
  0x29, 0xd0, 0x25, 0x20 // eor cs r13 r5 r9 LSR 32
};
const byte kInstruction_eor_cc_r13_r8_r1_LSR_1[] = {
  0xa1, 0xd0, 0x28, 0x30 // eor cc r13 r8 r1 LSR 1
};
const byte kInstruction_eor_cs_r7_r9_r10_LSR_17[] = {
  0xaa, 0x78, 0x29, 0x20 // eor cs r7 r9 r10 LSR 17
};
const byte kInstruction_eor_vc_r2_r1_r7_LSR_29[] = {
  0xa7, 0x2e, 0x21, 0x70 // eor vc r2 r1 r7 LSR 29
};
const byte kInstruction_eor_hi_r9_r2_r1_ASR_17[] = {
  0xc1, 0x98, 0x22, 0x80 // eor hi r9 r2 r1 ASR 17
};
const byte kInstruction_eor_cc_r14_r14_r7_ASR_17[] = {
  0xc7, 0xe8, 0x2e, 0x30 // eor cc r14 r14 r7 ASR 17
};
const byte kInstruction_eor_vs_r4_r8_r1_LSR_17[] = {
  0xa1, 0x48, 0x28, 0x60 // eor vs r4 r8 r1 LSR 17
};
const byte kInstruction_eor_vs_r8_r0_r6_LSR_8[] = {
  0x26, 0x84, 0x20, 0x60 // eor vs r8 r0 r6 LSR 8
};
const byte kInstruction_eor_vs_r8_r0_r14_LSR_12[] = {
  0x2e, 0x86, 0x20, 0x60 // eor vs r8 r0 r14 LSR 12
};
const byte kInstruction_eor_vc_r5_r8_r1_ASR_10[] = {
  0x41, 0x55, 0x28, 0x70 // eor vc r5 r8 r1 ASR 10
};
const byte kInstruction_eor_eq_r2_r0_r5_ASR_12[] = {
  0x45, 0x26, 0x20, 0x00 // eor eq r2 r0 r5 ASR 12
};
const byte kInstruction_eor_vc_r13_r2_r11_LSR_27[] = {
  0xab, 0xdd, 0x22, 0x70 // eor vc r13 r2 r11 LSR 27
};
const byte kInstruction_eor_vc_r9_r3_r1_LSR_15[] = {
  0xa1, 0x97, 0x23, 0x70 // eor vc r9 r3 r1 LSR 15
};
const byte kInstruction_eor_gt_r3_r11_r10_ASR_19[] = {
  0xca, 0x39, 0x2b, 0xc0 // eor gt r3 r11 r10 ASR 19
};
const byte kInstruction_eor_pl_r1_r0_r6_ASR_23[] = {
  0xc6, 0x1b, 0x20, 0x50 // eor pl r1 r0 r6 ASR 23
};
const byte kInstruction_eor_ls_r3_r7_r8_LSR_8[] = {
  0x28, 0x34, 0x27, 0x90 // eor ls r3 r7 r8 LSR 8
};
const byte kInstruction_eor_ls_r12_r14_r11_LSR_22[] = {
  0x2b, 0xcb, 0x2e, 0x90 // eor ls r12 r14 r11 LSR 22
};
const byte kInstruction_eor_vc_r5_r3_r8_ASR_6[] = {
  0x48, 0x53, 0x23, 0x70 // eor vc r5 r3 r8 ASR 6
};
const byte kInstruction_eor_le_r4_r13_r14_LSR_10[] = {
  0x2e, 0x45, 0x2d, 0xd0 // eor le r4 r13 r14 LSR 10
};
const byte kInstruction_eor_vc_r7_r4_r14_ASR_8[] = {
  0x4e, 0x74, 0x24, 0x70 // eor vc r7 r4 r14 ASR 8
};
const byte kInstruction_eor_ge_r3_r7_r8_LSR_3[] = {
  0xa8, 0x31, 0x27, 0xa0 // eor ge r3 r7 r8 LSR 3
};
const byte kInstruction_eor_al_r13_r8_r4_LSR_18[] = {
  0x24, 0xd9, 0x28, 0xe0 // eor al r13 r8 r4 LSR 18
};
const byte kInstruction_eor_gt_r7_r0_r6_ASR_21[] = {
  0xc6, 0x7a, 0x20, 0xc0 // eor gt r7 r0 r6 ASR 21
};
const byte kInstruction_eor_al_r3_r11_r13_LSR_31[] = {
  0xad, 0x3f, 0x2b, 0xe0 // eor al r3 r11 r13 LSR 31
};
const byte kInstruction_eor_le_r5_r0_r11_ASR_6[] = {
  0x4b, 0x53, 0x20, 0xd0 // eor le r5 r0 r11 ASR 6
};
const byte kInstruction_eor_cc_r11_r2_r5_LSR_26[] = {
  0x25, 0xbd, 0x22, 0x30 // eor cc r11 r2 r5 LSR 26
};
const byte kInstruction_eor_eq_r10_r14_r7_ASR_8[] = {
  0x47, 0xa4, 0x2e, 0x00 // eor eq r10 r14 r7 ASR 8
};
const byte kInstruction_eor_ne_r0_r0_r5_LSR_3[] = {
  0xa5, 0x01, 0x20, 0x10 // eor ne r0 r0 r5 LSR 3
};
const byte kInstruction_eor_mi_r9_r1_r2_ASR_6[] = {
  0x42, 0x93, 0x21, 0x40 // eor mi r9 r1 r2 ASR 6
};
const byte kInstruction_eor_eq_r6_r10_r13_ASR_17[] = {
  0xcd, 0x68, 0x2a, 0x00 // eor eq r6 r10 r13 ASR 17
};
const byte kInstruction_eor_hi_r2_r7_r0_ASR_32[] = {
  0x40, 0x20, 0x27, 0x80 // eor hi r2 r7 r0 ASR 32
};
const byte kInstruction_eor_ge_r14_r3_r11_LSR_17[] = {
  0xab, 0xe8, 0x23, 0xa0 // eor ge r14 r3 r11 LSR 17
};
const byte kInstruction_eor_cc_r6_r4_r5_LSR_4[] = {
  0x25, 0x62, 0x24, 0x30 // eor cc r6 r4 r5 LSR 4
};
const byte kInstruction_eor_al_r9_r14_r3_LSR_32[] = {
  0x23, 0x90, 0x2e, 0xe0 // eor al r9 r14 r3 LSR 32
};
const byte kInstruction_eor_vc_r14_r14_r6_LSR_23[] = {
  0xa6, 0xeb, 0x2e, 0x70 // eor vc r14 r14 r6 LSR 23
};
const byte kInstruction_eor_le_r1_r9_r7_ASR_6[] = {
  0x47, 0x13, 0x29, 0xd0 // eor le r1 r9 r7 ASR 6
};
const byte kInstruction_eor_mi_r2_r11_r7_ASR_5[] = {
  0xc7, 0x22, 0x2b, 0x40 // eor mi r2 r11 r7 ASR 5
};
const byte kInstruction_eor_le_r3_r14_r9_LSR_25[] = {
  0xa9, 0x3c, 0x2e, 0xd0 // eor le r3 r14 r9 LSR 25
};
const byte kInstruction_eor_mi_r10_r8_r10_ASR_25[] = {
  0xca, 0xac, 0x28, 0x40 // eor mi r10 r8 r10 ASR 25
};
const byte kInstruction_eor_eq_r5_r9_r5_LSR_24[] = {
  0x25, 0x5c, 0x29, 0x00 // eor eq r5 r9 r5 LSR 24
};
const byte kInstruction_eor_al_r2_r3_r13_ASR_24[] = {
  0x4d, 0x2c, 0x23, 0xe0 // eor al r2 r3 r13 ASR 24
};
const byte kInstruction_eor_cc_r6_r3_r7_ASR_23[] = {
  0xc7, 0x6b, 0x23, 0x30 // eor cc r6 r3 r7 ASR 23
};
const byte kInstruction_eor_ge_r11_r11_r13_LSR_7[] = {
  0xad, 0xb3, 0x2b, 0xa0 // eor ge r11 r11 r13 LSR 7
};
const byte kInstruction_eor_vc_r14_r1_r3_ASR_17[] = {
  0xc3, 0xe8, 0x21, 0x70 // eor vc r14 r1 r3 ASR 17
};
const byte kInstruction_eor_ls_r5_r1_r14_ASR_3[] = {
  0xce, 0x51, 0x21, 0x90 // eor ls r5 r1 r14 ASR 3
};
const byte kInstruction_eor_ge_r13_r5_r4_LSR_18[] = {
  0x24, 0xd9, 0x25, 0xa0 // eor ge r13 r5 r4 LSR 18
};
const byte kInstruction_eor_gt_r6_r5_r14_LSR_6[] = {
  0x2e, 0x63, 0x25, 0xc0 // eor gt r6 r5 r14 LSR 6
};
const byte kInstruction_eor_eq_r9_r6_r7_LSR_11[] = {
  0xa7, 0x95, 0x26, 0x00 // eor eq r9 r6 r7 LSR 11
};
const byte kInstruction_eor_eq_r14_r6_r12_ASR_27[] = {
  0xcc, 0xed, 0x26, 0x00 // eor eq r14 r6 r12 ASR 27
};
const byte kInstruction_eor_pl_r14_r14_r9_ASR_19[] = {
  0xc9, 0xe9, 0x2e, 0x50 // eor pl r14 r14 r9 ASR 19
};
const byte kInstruction_eor_le_r14_r12_r8_LSR_13[] = {
  0xa8, 0xe6, 0x2c, 0xd0 // eor le r14 r12 r8 LSR 13
};
const byte kInstruction_eor_cc_r7_r5_r5_LSR_13[] = {
  0xa5, 0x76, 0x25, 0x30 // eor cc r7 r5 r5 LSR 13
};
const byte kInstruction_eor_eq_r2_r13_r4_ASR_19[] = {
  0xc4, 0x29, 0x2d, 0x00 // eor eq r2 r13 r4 ASR 19
};
const byte kInstruction_eor_vs_r11_r11_r10_ASR_2[] = {
  0x4a, 0xb1, 0x2b, 0x60 // eor vs r11 r11 r10 ASR 2
};
const byte kInstruction_eor_cc_r10_r8_r8_LSR_23[] = {
  0xa8, 0xab, 0x28, 0x30 // eor cc r10 r8 r8 LSR 23
};
const byte kInstruction_eor_ls_r14_r12_r6_ASR_30[] = {
  0x46, 0xef, 0x2c, 0x90 // eor ls r14 r12 r6 ASR 30
};
const byte kInstruction_eor_hi_r8_r8_r6_ASR_19[] = {
  0xc6, 0x89, 0x28, 0x80 // eor hi r8 r8 r6 ASR 19
};
const byte kInstruction_eor_cs_r5_r12_r3_ASR_6[] = {
  0x43, 0x53, 0x2c, 0x20 // eor cs r5 r12 r3 ASR 6
};
const byte kInstruction_eor_vs_r0_r9_r14_ASR_5[] = {
  0xce, 0x02, 0x29, 0x60 // eor vs r0 r9 r14 ASR 5
};
const byte kInstruction_eor_lt_r9_r6_r14_ASR_7[] = {
  0xce, 0x93, 0x26, 0xb0 // eor lt r9 r6 r14 ASR 7
};
const byte kInstruction_eor_lt_r5_r1_r11_ASR_3[] = {
  0xcb, 0x51, 0x21, 0xb0 // eor lt r5 r1 r11 ASR 3
};
const byte kInstruction_eor_al_r4_r11_r3_LSR_14[] = {
  0x23, 0x47, 0x2b, 0xe0 // eor al r4 r11 r3 LSR 14
};
const byte kInstruction_eor_cs_r7_r1_r3_LSR_10[] = {
  0x23, 0x75, 0x21, 0x20 // eor cs r7 r1 r3 LSR 10
};
const byte kInstruction_eor_cc_r2_r11_r4_ASR_29[] = {
  0xc4, 0x2e, 0x2b, 0x30 // eor cc r2 r11 r4 ASR 29
};
const byte kInstruction_eor_eq_r7_r1_r4_LSR_31[] = {
  0xa4, 0x7f, 0x21, 0x00 // eor eq r7 r1 r4 LSR 31
};
const byte kInstruction_eor_hi_r2_r13_r7_ASR_17[] = {
  0xc7, 0x28, 0x2d, 0x80 // eor hi r2 r13 r7 ASR 17
};
const byte kInstruction_eor_cs_r12_r10_r9_ASR_4[] = {
  0x49, 0xc2, 0x2a, 0x20 // eor cs r12 r10 r9 ASR 4
};
const byte kInstruction_eor_gt_r10_r2_r2_LSR_28[] = {
  0x22, 0xae, 0x22, 0xc0 // eor gt r10 r2 r2 LSR 28
};
const byte kInstruction_eor_gt_r13_r12_r0_ASR_2[] = {
  0x40, 0xd1, 0x2c, 0xc0 // eor gt r13 r12 r0 ASR 2
};
const byte kInstruction_eor_pl_r14_r8_r7_LSR_1[] = {
  0xa7, 0xe0, 0x28, 0x50 // eor pl r14 r8 r7 LSR 1
};
const byte kInstruction_eor_hi_r2_r13_r3_ASR_20[] = {
  0x43, 0x2a, 0x2d, 0x80 // eor hi r2 r13 r3 ASR 20
};
const byte kInstruction_eor_lt_r2_r3_r3_LSR_13[] = {
  0xa3, 0x26, 0x23, 0xb0 // eor lt r2 r3 r3 LSR 13
};
const byte kInstruction_eor_mi_r11_r1_r12_ASR_24[] = {
  0x4c, 0xbc, 0x21, 0x40 // eor mi r11 r1 r12 ASR 24
};
const byte kInstruction_eor_vs_r8_r8_r8_LSR_1[] = {
  0xa8, 0x80, 0x28, 0x60 // eor vs r8 r8 r8 LSR 1
};
const byte kInstruction_eor_ne_r2_r14_r3_ASR_31[] = {
  0xc3, 0x2f, 0x2e, 0x10 // eor ne r2 r14 r3 ASR 31
};
const byte kInstruction_eor_lt_r8_r5_r1_LSR_11[] = {
  0xa1, 0x85, 0x25, 0xb0 // eor lt r8 r5 r1 LSR 11
};
const byte kInstruction_eor_pl_r4_r9_r8_ASR_31[] = {
  0xc8, 0x4f, 0x29, 0x50 // eor pl r4 r9 r8 ASR 31
};
const byte kInstruction_eor_ls_r8_r1_r13_ASR_4[] = {
  0x4d, 0x82, 0x21, 0x90 // eor ls r8 r1 r13 ASR 4
};
const byte kInstruction_eor_al_r2_r9_r14_LSR_16[] = {
  0x2e, 0x28, 0x29, 0xe0 // eor al r2 r9 r14 LSR 16
};
const byte kInstruction_eor_cs_r3_r6_r10_ASR_5[] = {
  0xca, 0x32, 0x26, 0x20 // eor cs r3 r6 r10 ASR 5
};
const byte kInstruction_eor_eq_r4_r12_r6_ASR_9[] = {
  0xc6, 0x44, 0x2c, 0x00 // eor eq r4 r12 r6 ASR 9
};
const byte kInstruction_eor_al_r12_r12_r4_ASR_32[] = {
  0x44, 0xc0, 0x2c, 0xe0 // eor al r12 r12 r4 ASR 32
};
const byte kInstruction_eor_pl_r1_r6_r11_LSR_19[] = {
  0xab, 0x19, 0x26, 0x50 // eor pl r1 r6 r11 LSR 19
};
const byte kInstruction_eor_pl_r8_r2_r1_LSR_13[] = {
  0xa1, 0x86, 0x22, 0x50 // eor pl r8 r2 r1 LSR 13
};
const byte kInstruction_eor_gt_r2_r11_r2_LSR_23[] = {
  0xa2, 0x2b, 0x2b, 0xc0 // eor gt r2 r11 r2 LSR 23
};
const byte kInstruction_eor_eq_r14_r8_r6_ASR_31[] = {
  0xc6, 0xef, 0x28, 0x00 // eor eq r14 r8 r6 ASR 31
};
const byte kInstruction_eor_cc_r6_r5_r7_ASR_31[] = {
  0xc7, 0x6f, 0x25, 0x30 // eor cc r6 r5 r7 ASR 31
};
const byte kInstruction_eor_cs_r14_r10_r11_ASR_28[] = {
  0x4b, 0xee, 0x2a, 0x20 // eor cs r14 r10 r11 ASR 28
};
const byte kInstruction_eor_le_r9_r9_r4_LSR_22[] = {
  0x24, 0x9b, 0x29, 0xd0 // eor le r9 r9 r4 LSR 22
};
const byte kInstruction_eor_cs_r4_r1_r14_ASR_11[] = {
  0xce, 0x45, 0x21, 0x20 // eor cs r4 r1 r14 ASR 11
};
const byte kInstruction_eor_ne_r6_r0_r9_LSR_30[] = {
  0x29, 0x6f, 0x20, 0x10 // eor ne r6 r0 r9 LSR 30
};
const byte kInstruction_eor_gt_r8_r6_r6_ASR_16[] = {
  0x46, 0x88, 0x26, 0xc0 // eor gt r8 r6 r6 ASR 16
};
const byte kInstruction_eor_pl_r11_r3_r5_ASR_4[] = {
  0x45, 0xb2, 0x23, 0x50 // eor pl r11 r3 r5 ASR 4
};
const byte kInstruction_eor_cs_r6_r3_r5_LSR_20[] = {
  0x25, 0x6a, 0x23, 0x20 // eor cs r6 r3 r5 LSR 20
};
const byte kInstruction_eor_cc_r1_r9_r13_LSR_26[] = {
  0x2d, 0x1d, 0x29, 0x30 // eor cc r1 r9 r13 LSR 26
};
const byte kInstruction_eor_vc_r5_r11_r2_ASR_14[] = {
  0x42, 0x57, 0x2b, 0x70 // eor vc r5 r11 r2 ASR 14
};
const byte kInstruction_eor_vc_r11_r0_r0_ASR_12[] = {
  0x40, 0xb6, 0x20, 0x70 // eor vc r11 r0 r0 ASR 12
};
const byte kInstruction_eor_mi_r3_r8_r2_LSR_7[] = {
  0xa2, 0x33, 0x28, 0x40 // eor mi r3 r8 r2 LSR 7
};
const byte kInstruction_eor_eq_r11_r2_r11_ASR_32[] = {
  0x4b, 0xb0, 0x22, 0x00 // eor eq r11 r2 r11 ASR 32
};
const byte kInstruction_eor_vc_r6_r0_r9_LSR_5[] = {
  0xa9, 0x62, 0x20, 0x70 // eor vc r6 r0 r9 LSR 5
};
const byte kInstruction_eor_gt_r4_r10_r13_LSR_15[] = {
  0xad, 0x47, 0x2a, 0xc0 // eor gt r4 r10 r13 LSR 15
};
const byte kInstruction_eor_mi_r5_r13_r14_LSR_30[] = {
  0x2e, 0x5f, 0x2d, 0x40 // eor mi r5 r13 r14 LSR 30
};
const byte kInstruction_eor_ge_r2_r13_r12_LSR_12[] = {
  0x2c, 0x26, 0x2d, 0xa0 // eor ge r2 r13 r12 LSR 12
};
const byte kInstruction_eor_ge_r0_r3_r2_LSR_2[] = {
  0x22, 0x01, 0x23, 0xa0 // eor ge r0 r3 r2 LSR 2
};
const byte kInstruction_eor_lt_r12_r10_r0_LSR_7[] = {
  0xa0, 0xc3, 0x2a, 0xb0 // eor lt r12 r10 r0 LSR 7
};
const byte kInstruction_eor_hi_r11_r8_r0_LSR_15[] = {
  0xa0, 0xb7, 0x28, 0x80 // eor hi r11 r8 r0 LSR 15
};
const byte kInstruction_eor_le_r9_r10_r5_LSR_31[] = {
  0xa5, 0x9f, 0x2a, 0xd0 // eor le r9 r10 r5 LSR 31
};
const byte kInstruction_eor_cs_r5_r3_r3_LSR_5[] = {
  0xa3, 0x52, 0x23, 0x20 // eor cs r5 r3 r3 LSR 5
};
const byte kInstruction_eor_mi_r8_r0_r4_ASR_1[] = {
  0xc4, 0x80, 0x20, 0x40 // eor mi r8 r0 r4 ASR 1
};
const byte kInstruction_eor_lt_r2_r6_r10_ASR_22[] = {
  0x4a, 0x2b, 0x26, 0xb0 // eor lt r2 r6 r10 ASR 22
};
const byte kInstruction_eor_cc_r8_r4_r12_ASR_22[] = {
  0x4c, 0x8b, 0x24, 0x30 // eor cc r8 r4 r12 ASR 22
};
const byte kInstruction_eor_vc_r10_r0_r12_ASR_21[] = {
  0xcc, 0xaa, 0x20, 0x70 // eor vc r10 r0 r12 ASR 21
};
const byte kInstruction_eor_mi_r14_r8_r9_ASR_26[] = {
  0x49, 0xed, 0x28, 0x40 // eor mi r14 r8 r9 ASR 26
};
const byte kInstruction_eor_al_r2_r4_r9_LSR_23[] = {
  0xa9, 0x2b, 0x24, 0xe0 // eor al r2 r4 r9 LSR 23
};
const byte kInstruction_eor_mi_r3_r0_r0_ASR_22[] = {
  0x40, 0x3b, 0x20, 0x40 // eor mi r3 r0 r0 ASR 22
};
const byte kInstruction_eor_ge_r6_r0_r7_ASR_8[] = {
  0x47, 0x64, 0x20, 0xa0 // eor ge r6 r0 r7 ASR 8
};
const byte kInstruction_eor_ls_r7_r14_r8_ASR_23[] = {
  0xc8, 0x7b, 0x2e, 0x90 // eor ls r7 r14 r8 ASR 23
};
const byte kInstruction_eor_ne_r6_r5_r12_LSR_30[] = {
  0x2c, 0x6f, 0x25, 0x10 // eor ne r6 r5 r12 LSR 30
};
const byte kInstruction_eor_ge_r5_r1_r3_ASR_29[] = {
  0xc3, 0x5e, 0x21, 0xa0 // eor ge r5 r1 r3 ASR 29
};
const byte kInstruction_eor_cc_r2_r10_r2_ASR_17[] = {
  0xc2, 0x28, 0x2a, 0x30 // eor cc r2 r10 r2 ASR 17
};
const byte kInstruction_eor_ne_r6_r4_r3_LSR_2[] = {
  0x23, 0x61, 0x24, 0x10 // eor ne r6 r4 r3 LSR 2
};
const byte kInstruction_eor_vs_r10_r13_r11_LSR_19[] = {
  0xab, 0xa9, 0x2d, 0x60 // eor vs r10 r13 r11 LSR 19
};
const byte kInstruction_eor_hi_r0_r0_r8_LSR_27[] = {
  0xa8, 0x0d, 0x20, 0x80 // eor hi r0 r0 r8 LSR 27
};
const byte kInstruction_eor_gt_r4_r3_r9_LSR_16[] = {
  0x29, 0x48, 0x23, 0xc0 // eor gt r4 r3 r9 LSR 16
};
const byte kInstruction_eor_lt_r13_r11_r1_LSR_21[] = {
  0xa1, 0xda, 0x2b, 0xb0 // eor lt r13 r11 r1 LSR 21
};
const byte kInstruction_eor_mi_r13_r10_r2_LSR_30[] = {
  0x22, 0xdf, 0x2a, 0x40 // eor mi r13 r10 r2 LSR 30
};
const byte kInstruction_eor_mi_r4_r13_r2_LSR_19[] = {
  0xa2, 0x49, 0x2d, 0x40 // eor mi r4 r13 r2 LSR 19
};
const byte kInstruction_eor_vs_r6_r3_r5_LSR_8[] = {
  0x25, 0x64, 0x23, 0x60 // eor vs r6 r3 r5 LSR 8
};
const byte kInstruction_eor_ls_r9_r12_r9_ASR_28[] = {
  0x49, 0x9e, 0x2c, 0x90 // eor ls r9 r12 r9 ASR 28
};
const byte kInstruction_eor_al_r1_r2_r2_ASR_3[] = {
  0xc2, 0x11, 0x22, 0xe0 // eor al r1 r2 r2 ASR 3
};
const byte kInstruction_eor_ls_r11_r11_r3_LSR_2[] = {
  0x23, 0xb1, 0x2b, 0x90 // eor ls r11 r11 r3 LSR 2
};
const byte kInstruction_eor_al_r10_r3_r5_LSR_2[] = {
  0x25, 0xa1, 0x23, 0xe0 // eor al r10 r3 r5 LSR 2
};
const byte kInstruction_eor_eq_r1_r11_r1_LSR_14[] = {
  0x21, 0x17, 0x2b, 0x00 // eor eq r1 r11 r1 LSR 14
};
const byte kInstruction_eor_mi_r0_r1_r4_ASR_12[] = {
  0x44, 0x06, 0x21, 0x40 // eor mi r0 r1 r4 ASR 12
};
const byte kInstruction_eor_pl_r0_r3_r0_LSR_5[] = {
  0xa0, 0x02, 0x23, 0x50 // eor pl r0 r3 r0 LSR 5
};
const byte kInstruction_eor_mi_r2_r2_r8_LSR_27[] = {
  0xa8, 0x2d, 0x22, 0x40 // eor mi r2 r2 r8 LSR 27
};
const byte kInstruction_eor_ls_r13_r1_r13_LSR_20[] = {
  0x2d, 0xda, 0x21, 0x90 // eor ls r13 r1 r13 LSR 20
};
const byte kInstruction_eor_cs_r1_r4_r1_ASR_5[] = {
  0xc1, 0x12, 0x24, 0x20 // eor cs r1 r4 r1 ASR 5
};
const byte kInstruction_eor_ge_r5_r9_r1_ASR_6[] = {
  0x41, 0x53, 0x29, 0xa0 // eor ge r5 r9 r1 ASR 6
};
const byte kInstruction_eor_cc_r7_r8_r11_LSR_30[] = {
  0x2b, 0x7f, 0x28, 0x30 // eor cc r7 r8 r11 LSR 30
};
const byte kInstruction_eor_le_r1_r10_r8_LSR_12[] = {
  0x28, 0x16, 0x2a, 0xd0 // eor le r1 r10 r8 LSR 12
};
const byte kInstruction_eor_gt_r5_r5_r9_LSR_6[] = {
  0x29, 0x53, 0x25, 0xc0 // eor gt r5 r5 r9 LSR 6
};
const byte kInstruction_eor_eq_r14_r11_r13_LSR_21[] = {
  0xad, 0xea, 0x2b, 0x00 // eor eq r14 r11 r13 LSR 21
};
const byte kInstruction_eor_hi_r4_r10_r7_ASR_29[] = {
  0xc7, 0x4e, 0x2a, 0x80 // eor hi r4 r10 r7 ASR 29
};
const byte kInstruction_eor_ls_r12_r6_r13_LSR_30[] = {
  0x2d, 0xcf, 0x26, 0x90 // eor ls r12 r6 r13 LSR 30
};
const byte kInstruction_eor_cc_r1_r2_r13_ASR_31[] = {
  0xcd, 0x1f, 0x22, 0x30 // eor cc r1 r2 r13 ASR 31
};
const byte kInstruction_eor_cs_r4_r12_r12_ASR_31[] = {
  0xcc, 0x4f, 0x2c, 0x20 // eor cs r4 r12 r12 ASR 31
};
const byte kInstruction_eor_cs_r10_r8_r8_LSR_25[] = {
  0xa8, 0xac, 0x28, 0x20 // eor cs r10 r8 r8 LSR 25
};
const byte kInstruction_eor_eq_r11_r14_r12_ASR_9[] = {
  0xcc, 0xb4, 0x2e, 0x00 // eor eq r11 r14 r12 ASR 9
};
const byte kInstruction_eor_pl_r8_r7_r6_LSR_29[] = {
  0xa6, 0x8e, 0x27, 0x50 // eor pl r8 r7 r6 LSR 29
};
const byte kInstruction_eor_vs_r2_r3_r12_ASR_15[] = {
  0xcc, 0x27, 0x23, 0x60 // eor vs r2 r3 r12 ASR 15
};
const byte kInstruction_eor_vs_r10_r11_r9_ASR_31[] = {
  0xc9, 0xaf, 0x2b, 0x60 // eor vs r10 r11 r9 ASR 31
};
const byte kInstruction_eor_mi_r2_r4_r13_ASR_2[] = {
  0x4d, 0x21, 0x24, 0x40 // eor mi r2 r4 r13 ASR 2
};
const byte kInstruction_eor_ls_r3_r0_r1_LSR_25[] = {
  0xa1, 0x3c, 0x20, 0x90 // eor ls r3 r0 r1 LSR 25
};
const byte kInstruction_eor_pl_r7_r2_r12_LSR_16[] = {
  0x2c, 0x78, 0x22, 0x50 // eor pl r7 r2 r12 LSR 16
};
const byte kInstruction_eor_ge_r6_r14_r9_ASR_30[] = {
  0x49, 0x6f, 0x2e, 0xa0 // eor ge r6 r14 r9 ASR 30
};
const byte kInstruction_eor_pl_r2_r5_r4_ASR_11[] = {
  0xc4, 0x25, 0x25, 0x50 // eor pl r2 r5 r4 ASR 11
};
const byte kInstruction_eor_al_r5_r10_r11_ASR_23[] = {
  0xcb, 0x5b, 0x2a, 0xe0 // eor al r5 r10 r11 ASR 23
};
const byte kInstruction_eor_le_r4_r1_r9_LSR_28[] = {
  0x29, 0x4e, 0x21, 0xd0 // eor le r4 r1 r9 LSR 28
};
const byte kInstruction_eor_cc_r13_r4_r2_ASR_25[] = {
  0xc2, 0xdc, 0x24, 0x30 // eor cc r13 r4 r2 ASR 25
};
const byte kInstruction_eor_pl_r7_r7_r8_LSR_9[] = {
  0xa8, 0x74, 0x27, 0x50 // eor pl r7 r7 r8 LSR 9
};
const byte kInstruction_eor_le_r8_r11_r0_ASR_13[] = {
  0xc0, 0x86, 0x2b, 0xd0 // eor le r8 r11 r0 ASR 13
};
const byte kInstruction_eor_eq_r11_r9_r12_ASR_32[] = {
  0x4c, 0xb0, 0x29, 0x00 // eor eq r11 r9 r12 ASR 32
};
const byte kInstruction_eor_ls_r4_r0_r10_ASR_31[] = {
  0xca, 0x4f, 0x20, 0x90 // eor ls r4 r0 r10 ASR 31
};
const byte kInstruction_eor_gt_r10_r8_r4_LSR_22[] = {
  0x24, 0xab, 0x28, 0xc0 // eor gt r10 r8 r4 LSR 22
};
const byte kInstruction_eor_ne_r9_r8_r0_ASR_21[] = {
  0xc0, 0x9a, 0x28, 0x10 // eor ne r9 r8 r0 ASR 21
};
const byte kInstruction_eor_lt_r11_r9_r9_ASR_27[] = {
  0xc9, 0xbd, 0x29, 0xb0 // eor lt r11 r9 r9 ASR 27
};
const byte kInstruction_eor_vc_r14_r6_r14_LSR_22[] = {
  0x2e, 0xeb, 0x26, 0x70 // eor vc r14 r6 r14 LSR 22
};
const byte kInstruction_eor_vs_r12_r4_r14_LSR_12[] = {
  0x2e, 0xc6, 0x24, 0x60 // eor vs r12 r4 r14 LSR 12
};
const byte kInstruction_eor_lt_r7_r11_r6_ASR_9[] = {
  0xc6, 0x74, 0x2b, 0xb0 // eor lt r7 r11 r6 ASR 9
};
const byte kInstruction_eor_lt_r3_r13_r5_LSR_8[] = {
  0x25, 0x34, 0x2d, 0xb0 // eor lt r3 r13 r5 LSR 8
};
const byte kInstruction_eor_le_r2_r7_r6_ASR_11[] = {
  0xc6, 0x25, 0x27, 0xd0 // eor le r2 r7 r6 ASR 11
};
const byte kInstruction_eor_vc_r2_r0_r4_ASR_25[] = {
  0xc4, 0x2c, 0x20, 0x70 // eor vc r2 r0 r4 ASR 25
};
const byte kInstruction_eor_lt_r2_r11_r10_LSR_10[] = {
  0x2a, 0x25, 0x2b, 0xb0 // eor lt r2 r11 r10 LSR 10
};
const byte kInstruction_eor_al_r7_r9_r12_ASR_13[] = {
  0xcc, 0x76, 0x29, 0xe0 // eor al r7 r9 r12 ASR 13
};
const byte kInstruction_eor_cs_r13_r0_r2_LSR_2[] = {
  0x22, 0xd1, 0x20, 0x20 // eor cs r13 r0 r2 LSR 2
};
const byte kInstruction_eor_cc_r0_r6_r0_LSR_23[] = {
  0xa0, 0x0b, 0x26, 0x30 // eor cc r0 r6 r0 LSR 23
};
const byte kInstruction_eor_vc_r10_r2_r12_LSR_21[] = {
  0xac, 0xaa, 0x22, 0x70 // eor vc r10 r2 r12 LSR 21
};
const byte kInstruction_eor_mi_r0_r1_r6_ASR_28[] = {
  0x46, 0x0e, 0x21, 0x40 // eor mi r0 r1 r6 ASR 28
};
const byte kInstruction_eor_hi_r0_r12_r1_LSR_23[] = {
  0xa1, 0x0b, 0x2c, 0x80 // eor hi r0 r12 r1 LSR 23
};
const byte kInstruction_eor_eq_r10_r7_r3_ASR_6[] = {
  0x43, 0xa3, 0x27, 0x00 // eor eq r10 r7 r3 ASR 6
};
const byte kInstruction_eor_hi_r9_r13_r9_ASR_9[] = {
  0xc9, 0x94, 0x2d, 0x80 // eor hi r9 r13 r9 ASR 9
};
const byte kInstruction_eor_le_r4_r14_r1_LSR_13[] = {
  0xa1, 0x46, 0x2e, 0xd0 // eor le r4 r14 r1 LSR 13
};
const byte kInstruction_eor_vs_r9_r12_r12_LSR_2[] = {
  0x2c, 0x91, 0x2c, 0x60 // eor vs r9 r12 r12 LSR 2
};
const byte kInstruction_eor_vc_r11_r3_r4_ASR_7[] = {
  0xc4, 0xb3, 0x23, 0x70 // eor vc r11 r3 r4 ASR 7
};
const byte kInstruction_eor_mi_r13_r8_r3_LSR_8[] = {
  0x23, 0xd4, 0x28, 0x40 // eor mi r13 r8 r3 LSR 8
};
const byte kInstruction_eor_eq_r6_r12_r1_LSR_12[] = {
  0x21, 0x66, 0x2c, 0x00 // eor eq r6 r12 r1 LSR 12
};
const byte kInstruction_eor_le_r10_r11_r4_LSR_27[] = {
  0xa4, 0xad, 0x2b, 0xd0 // eor le r10 r11 r4 LSR 27
};
const byte kInstruction_eor_le_r7_r0_r1_ASR_15[] = {
  0xc1, 0x77, 0x20, 0xd0 // eor le r7 r0 r1 ASR 15
};
const byte kInstruction_eor_ne_r12_r0_r10_ASR_13[] = {
  0xca, 0xc6, 0x20, 0x10 // eor ne r12 r0 r10 ASR 13
};
const byte kInstruction_eor_hi_r1_r11_r12_ASR_1[] = {
  0xcc, 0x10, 0x2b, 0x80 // eor hi r1 r11 r12 ASR 1
};
const byte kInstruction_eor_cs_r2_r12_r10_ASR_28[] = {
  0x4a, 0x2e, 0x2c, 0x20 // eor cs r2 r12 r10 ASR 28
};
const byte kInstruction_eor_vc_r0_r7_r14_LSR_4[] = {
  0x2e, 0x02, 0x27, 0x70 // eor vc r0 r7 r14 LSR 4
};
const byte kInstruction_eor_gt_r9_r8_r6_LSR_6[] = {
  0x26, 0x93, 0x28, 0xc0 // eor gt r9 r8 r6 LSR 6
};
const byte kInstruction_eor_cc_r9_r8_r11_ASR_5[] = {
  0xcb, 0x92, 0x28, 0x30 // eor cc r9 r8 r11 ASR 5
};
const byte kInstruction_eor_le_r0_r12_r4_ASR_22[] = {
  0x44, 0x0b, 0x2c, 0xd0 // eor le r0 r12 r4 ASR 22
};
const byte kInstruction_eor_vs_r6_r4_r14_ASR_2[] = {
  0x4e, 0x61, 0x24, 0x60 // eor vs r6 r4 r14 ASR 2
};
const byte kInstruction_eor_le_r1_r13_r12_ASR_14[] = {
  0x4c, 0x17, 0x2d, 0xd0 // eor le r1 r13 r12 ASR 14
};
const byte kInstruction_eor_le_r0_r3_r3_LSR_6[] = {
  0x23, 0x03, 0x23, 0xd0 // eor le r0 r3 r3 LSR 6
};
const byte kInstruction_eor_ls_r2_r7_r3_ASR_23[] = {
  0xc3, 0x2b, 0x27, 0x90 // eor ls r2 r7 r3 ASR 23
};
const byte kInstruction_eor_ge_r12_r3_r11_LSR_13[] = {
  0xab, 0xc6, 0x23, 0xa0 // eor ge r12 r3 r11 LSR 13
};
const byte kInstruction_eor_ne_r3_r0_r9_LSR_16[] = {
  0x29, 0x38, 0x20, 0x10 // eor ne r3 r0 r9 LSR 16
};
const byte kInstruction_eor_ge_r5_r14_r10_ASR_24[] = {
  0x4a, 0x5c, 0x2e, 0xa0 // eor ge r5 r14 r10 ASR 24
};
const byte kInstruction_eor_eq_r14_r4_r1_ASR_16[] = {
  0x41, 0xe8, 0x24, 0x00 // eor eq r14 r4 r1 ASR 16
};
const byte kInstruction_eor_cs_r5_r1_r9_ASR_17[] = {
  0xc9, 0x58, 0x21, 0x20 // eor cs r5 r1 r9 ASR 17
};
const byte kInstruction_eor_mi_r4_r7_r2_LSR_17[] = {
  0xa2, 0x48, 0x27, 0x40 // eor mi r4 r7 r2 LSR 17
};
const byte kInstruction_eor_ne_r9_r0_r7_LSR_18[] = {
  0x27, 0x99, 0x20, 0x10 // eor ne r9 r0 r7 LSR 18
};
const byte kInstruction_eor_al_r5_r2_r13_LSR_12[] = {
  0x2d, 0x56, 0x22, 0xe0 // eor al r5 r2 r13 LSR 12
};
const byte kInstruction_eor_pl_r12_r13_r1_LSR_28[] = {
  0x21, 0xce, 0x2d, 0x50 // eor pl r12 r13 r1 LSR 28
};
const byte kInstruction_eor_vc_r9_r7_r4_ASR_7[] = {
  0xc4, 0x93, 0x27, 0x70 // eor vc r9 r7 r4 ASR 7
};
const byte kInstruction_eor_le_r4_r11_r9_ASR_5[] = {
  0xc9, 0x42, 0x2b, 0xd0 // eor le r4 r11 r9 ASR 5
};
const byte kInstruction_eor_cc_r1_r14_r3_ASR_26[] = {
  0x43, 0x1d, 0x2e, 0x30 // eor cc r1 r14 r3 ASR 26
};
const byte kInstruction_eor_le_r1_r2_r1_LSR_27[] = {
  0xa1, 0x1d, 0x22, 0xd0 // eor le r1 r2 r1 LSR 27
};
const byte kInstruction_eor_ge_r14_r0_r5_LSR_11[] = {
  0xa5, 0xe5, 0x20, 0xa0 // eor ge r14 r0 r5 LSR 11
};
const byte kInstruction_eor_cc_r5_r5_r0_ASR_19[] = {
  0xc0, 0x59, 0x25, 0x30 // eor cc r5 r5 r0 ASR 19
};
const byte kInstruction_eor_ne_r11_r11_r6_LSR_4[] = {
  0x26, 0xb2, 0x2b, 0x10 // eor ne r11 r11 r6 LSR 4
};
const byte kInstruction_eor_vc_r13_r10_r9_LSR_18[] = {
  0x29, 0xd9, 0x2a, 0x70 // eor vc r13 r10 r9 LSR 18
};
const byte kInstruction_eor_hi_r10_r10_r7_ASR_26[] = {
  0x47, 0xad, 0x2a, 0x80 // eor hi r10 r10 r7 ASR 26
};
const byte kInstruction_eor_al_r2_r8_r12_ASR_21[] = {
  0xcc, 0x2a, 0x28, 0xe0 // eor al r2 r8 r12 ASR 21
};
const byte kInstruction_eor_vc_r5_r4_r6_LSR_5[] = {
  0xa6, 0x52, 0x24, 0x70 // eor vc r5 r4 r6 LSR 5
};
const byte kInstruction_eor_cc_r0_r9_r7_LSR_24[] = {
  0x27, 0x0c, 0x29, 0x30 // eor cc r0 r9 r7 LSR 24
};
const byte kInstruction_eor_ls_r10_r9_r3_LSR_32[] = {
  0x23, 0xa0, 0x29, 0x90 // eor ls r10 r9 r3 LSR 32
};
const byte kInstruction_eor_vc_r8_r12_r7_ASR_14[] = {
  0x47, 0x87, 0x2c, 0x70 // eor vc r8 r12 r7 ASR 14
};
const byte kInstruction_eor_le_r6_r13_r8_ASR_15[] = {
  0xc8, 0x67, 0x2d, 0xd0 // eor le r6 r13 r8 ASR 15
};
const byte kInstruction_eor_le_r0_r0_r13_ASR_9[] = {
  0xcd, 0x04, 0x20, 0xd0 // eor le r0 r0 r13 ASR 9
};
const byte kInstruction_eor_eq_r9_r3_r0_ASR_5[] = {
  0xc0, 0x92, 0x23, 0x00 // eor eq r9 r3 r0 ASR 5
};
const byte kInstruction_eor_mi_r0_r7_r5_LSR_21[] = {
  0xa5, 0x0a, 0x27, 0x40 // eor mi r0 r7 r5 LSR 21
};
const byte kInstruction_eor_mi_r13_r1_r8_LSR_19[] = {
  0xa8, 0xd9, 0x21, 0x40 // eor mi r13 r1 r8 LSR 19
};
const byte kInstruction_eor_le_r7_r0_r7_ASR_26[] = {
  0x47, 0x7d, 0x20, 0xd0 // eor le r7 r0 r7 ASR 26
};
const byte kInstruction_eor_mi_r7_r4_r3_ASR_20[] = {
  0x43, 0x7a, 0x24, 0x40 // eor mi r7 r4 r3 ASR 20
};
const byte kInstruction_eor_al_r3_r5_r8_ASR_23[] = {
  0xc8, 0x3b, 0x25, 0xe0 // eor al r3 r5 r8 ASR 23
};
const byte kInstruction_eor_ge_r4_r12_r5_LSR_28[] = {
  0x25, 0x4e, 0x2c, 0xa0 // eor ge r4 r12 r5 LSR 28
};
const byte kInstruction_eor_vs_r7_r13_r13_ASR_1[] = {
  0xcd, 0x70, 0x2d, 0x60 // eor vs r7 r13 r13 ASR 1
};
const byte kInstruction_eor_gt_r8_r8_r11_LSR_23[] = {
  0xab, 0x8b, 0x28, 0xc0 // eor gt r8 r8 r11 LSR 23
};
const byte kInstruction_eor_eq_r13_r8_r4_ASR_7[] = {
  0xc4, 0xd3, 0x28, 0x00 // eor eq r13 r8 r4 ASR 7
};
const byte kInstruction_eor_eq_r14_r3_r13_LSR_12[] = {
  0x2d, 0xe6, 0x23, 0x00 // eor eq r14 r3 r13 LSR 12
};
const byte kInstruction_eor_vs_r5_r13_r10_ASR_21[] = {
  0xca, 0x5a, 0x2d, 0x60 // eor vs r5 r13 r10 ASR 21
};
const byte kInstruction_eor_vc_r4_r2_r8_ASR_31[] = {
  0xc8, 0x4f, 0x22, 0x70 // eor vc r4 r2 r8 ASR 31
};
const byte kInstruction_eor_vc_r2_r9_r12_ASR_18[] = {
  0x4c, 0x29, 0x29, 0x70 // eor vc r2 r9 r12 ASR 18
};
const byte kInstruction_eor_pl_r4_r8_r11_ASR_3[] = {
  0xcb, 0x41, 0x28, 0x50 // eor pl r4 r8 r11 ASR 3
};
const byte kInstruction_eor_cc_r11_r8_r1_ASR_13[] = {
  0xc1, 0xb6, 0x28, 0x30 // eor cc r11 r8 r1 ASR 13
};
const byte kInstruction_eor_pl_r11_r13_r2_ASR_11[] = {
  0xc2, 0xb5, 0x2d, 0x50 // eor pl r11 r13 r2 ASR 11
};
const byte kInstruction_eor_ge_r8_r5_r5_LSR_9[] = {
  0xa5, 0x84, 0x25, 0xa0 // eor ge r8 r5 r5 LSR 9
};
const byte kInstruction_eor_mi_r2_r6_r7_LSR_22[] = {
  0x27, 0x2b, 0x26, 0x40 // eor mi r2 r6 r7 LSR 22
};
const byte kInstruction_eor_cs_r0_r1_r1_LSR_27[] = {
  0xa1, 0x0d, 0x21, 0x20 // eor cs r0 r1 r1 LSR 27
};
const byte kInstruction_eor_vs_r2_r0_r5_ASR_22[] = {
  0x45, 0x2b, 0x20, 0x60 // eor vs r2 r0 r5 ASR 22
};
const byte kInstruction_eor_cs_r13_r1_r3_ASR_10[] = {
  0x43, 0xd5, 0x21, 0x20 // eor cs r13 r1 r3 ASR 10
};
const byte kInstruction_eor_vs_r5_r6_r8_LSR_24[] = {
  0x28, 0x5c, 0x26, 0x60 // eor vs r5 r6 r8 LSR 24
};
const byte kInstruction_eor_ge_r5_r2_r10_LSR_15[] = {
  0xaa, 0x57, 0x22, 0xa0 // eor ge r5 r2 r10 LSR 15
};
const byte kInstruction_eor_hi_r8_r10_r10_ASR_26[] = {
  0x4a, 0x8d, 0x2a, 0x80 // eor hi r8 r10 r10 ASR 26
};
const byte kInstruction_eor_vc_r7_r6_r11_LSR_19[] = {
  0xab, 0x79, 0x26, 0x70 // eor vc r7 r6 r11 LSR 19
};
const byte kInstruction_eor_ls_r7_r5_r0_LSR_1[] = {
  0xa0, 0x70, 0x25, 0x90 // eor ls r7 r5 r0 LSR 1
};
const byte kInstruction_eor_al_r9_r4_r12_LSR_28[] = {
  0x2c, 0x9e, 0x24, 0xe0 // eor al r9 r4 r12 LSR 28
};
const byte kInstruction_eor_vs_r2_r2_r5_ASR_19[] = {
  0xc5, 0x29, 0x22, 0x60 // eor vs r2 r2 r5 ASR 19
};
const byte kInstruction_eor_mi_r9_r12_r11_LSR_26[] = {
  0x2b, 0x9d, 0x2c, 0x40 // eor mi r9 r12 r11 LSR 26
};
const byte kInstruction_eor_ne_r13_r7_r8_LSR_6[] = {
  0x28, 0xd3, 0x27, 0x10 // eor ne r13 r7 r8 LSR 6
};
const byte kInstruction_eor_al_r13_r7_r0_LSR_20[] = {
  0x20, 0xda, 0x27, 0xe0 // eor al r13 r7 r0 LSR 20
};
const byte kInstruction_eor_eq_r5_r5_r4_ASR_9[] = {
  0xc4, 0x54, 0x25, 0x00 // eor eq r5 r5 r4 ASR 9
};
const byte kInstruction_eor_le_r7_r11_r10_ASR_16[] = {
  0x4a, 0x78, 0x2b, 0xd0 // eor le r7 r11 r10 ASR 16
};
const byte kInstruction_eor_lt_r14_r14_r13_LSR_3[] = {
  0xad, 0xe1, 0x2e, 0xb0 // eor lt r14 r14 r13 LSR 3
};
const byte kInstruction_eor_pl_r5_r9_r2_ASR_7[] = {
  0xc2, 0x53, 0x29, 0x50 // eor pl r5 r9 r2 ASR 7
};
const byte kInstruction_eor_cc_r2_r13_r14_LSR_13[] = {
  0xae, 0x26, 0x2d, 0x30 // eor cc r2 r13 r14 LSR 13
};
const byte kInstruction_eor_gt_r2_r8_r11_ASR_11[] = {
  0xcb, 0x25, 0x28, 0xc0 // eor gt r2 r8 r11 ASR 11
};
const byte kInstruction_eor_hi_r8_r12_r8_ASR_1[] = {
  0xc8, 0x80, 0x2c, 0x80 // eor hi r8 r12 r8 ASR 1
};
const byte kInstruction_eor_cc_r11_r12_r12_LSR_26[] = {
  0x2c, 0xbd, 0x2c, 0x30 // eor cc r11 r12 r12 LSR 26
};
const byte kInstruction_eor_eq_r6_r4_r1_ASR_27[] = {
  0xc1, 0x6d, 0x24, 0x00 // eor eq r6 r4 r1 ASR 27
};
const byte kInstruction_eor_eq_r7_r6_r7_ASR_17[] = {
  0xc7, 0x78, 0x26, 0x00 // eor eq r7 r6 r7 ASR 17
};
const byte kInstruction_eor_mi_r10_r12_r0_LSR_3[] = {
  0xa0, 0xa1, 0x2c, 0x40 // eor mi r10 r12 r0 LSR 3
};
const byte kInstruction_eor_ge_r2_r1_r5_ASR_20[] = {
  0x45, 0x2a, 0x21, 0xa0 // eor ge r2 r1 r5 ASR 20
};
const byte kInstruction_eor_lt_r12_r12_r3_ASR_25[] = {
  0xc3, 0xcc, 0x2c, 0xb0 // eor lt r12 r12 r3 ASR 25
};
const byte kInstruction_eor_mi_r11_r7_r8_ASR_13[] = {
  0xc8, 0xb6, 0x27, 0x40 // eor mi r11 r7 r8 ASR 13
};
const byte kInstruction_eor_al_r5_r5_r13_ASR_4[] = {
  0x4d, 0x52, 0x25, 0xe0 // eor al r5 r5 r13 ASR 4
};
const byte kInstruction_eor_eq_r8_r9_r4_LSR_5[] = {
  0xa4, 0x82, 0x29, 0x00 // eor eq r8 r9 r4 LSR 5
};
const byte kInstruction_eor_ne_r9_r5_r0_LSR_5[] = {
  0xa0, 0x92, 0x25, 0x10 // eor ne r9 r5 r0 LSR 5
};
const byte kInstruction_eor_hi_r4_r7_r7_ASR_22[] = {
  0x47, 0x4b, 0x27, 0x80 // eor hi r4 r7 r7 ASR 22
};
const byte kInstruction_eor_al_r13_r12_r14_ASR_26[] = {
  0x4e, 0xdd, 0x2c, 0xe0 // eor al r13 r12 r14 ASR 26
};
const byte kInstruction_eor_lt_r11_r6_r1_ASR_11[] = {
  0xc1, 0xb5, 0x26, 0xb0 // eor lt r11 r6 r1 ASR 11
};
const byte kInstruction_eor_cs_r4_r2_r11_LSR_27[] = {
  0xab, 0x4d, 0x22, 0x20 // eor cs r4 r2 r11 LSR 27
};
const byte kInstruction_eor_cc_r4_r5_r12_LSR_22[] = {
  0x2c, 0x4b, 0x25, 0x30 // eor cc r4 r5 r12 LSR 22
};
const byte kInstruction_eor_mi_r6_r1_r1_LSR_23[] = {
  0xa1, 0x6b, 0x21, 0x40 // eor mi r6 r1 r1 LSR 23
};
const byte kInstruction_eor_eq_r7_r1_r2_LSR_30[] = {
  0x22, 0x7f, 0x21, 0x00 // eor eq r7 r1 r2 LSR 30
};
const byte kInstruction_eor_al_r2_r13_r12_ASR_6[] = {
  0x4c, 0x23, 0x2d, 0xe0 // eor al r2 r13 r12 ASR 6
};
const byte kInstruction_eor_ge_r9_r13_r10_ASR_19[] = {
  0xca, 0x99, 0x2d, 0xa0 // eor ge r9 r13 r10 ASR 19
};
const byte kInstruction_eor_le_r1_r10_r9_LSR_3[] = {
  0xa9, 0x11, 0x2a, 0xd0 // eor le r1 r10 r9 LSR 3
};
const byte kInstruction_eor_le_r3_r11_r9_LSR_18[] = {
  0x29, 0x39, 0x2b, 0xd0 // eor le r3 r11 r9 LSR 18
};
const byte kInstruction_eor_vs_r1_r7_r13_LSR_23[] = {
  0xad, 0x1b, 0x27, 0x60 // eor vs r1 r7 r13 LSR 23
};
const byte kInstruction_eor_cc_r14_r9_r4_ASR_2[] = {
  0x44, 0xe1, 0x29, 0x30 // eor cc r14 r9 r4 ASR 2
};
const byte kInstruction_eor_mi_r1_r14_r2_ASR_15[] = {
  0xc2, 0x17, 0x2e, 0x40 // eor mi r1 r14 r2 ASR 15
};
const byte kInstruction_eor_ne_r8_r1_r14_ASR_32[] = {
  0x4e, 0x80, 0x21, 0x10 // eor ne r8 r1 r14 ASR 32
};
const byte kInstruction_eor_hi_r14_r12_r14_LSR_21[] = {
  0xae, 0xea, 0x2c, 0x80 // eor hi r14 r12 r14 LSR 21
};
const byte kInstruction_eor_lt_r6_r2_r0_LSR_1[] = {
  0xa0, 0x60, 0x22, 0xb0 // eor lt r6 r2 r0 LSR 1
};
const byte kInstruction_eor_ls_r5_r12_r4_ASR_4[] = {
  0x44, 0x52, 0x2c, 0x90 // eor ls r5 r12 r4 ASR 4
};
const byte kInstruction_eor_vs_r3_r12_r8_ASR_25[] = {
  0xc8, 0x3c, 0x2c, 0x60 // eor vs r3 r12 r8 ASR 25
};
const byte kInstruction_eor_hi_r11_r6_r11_LSR_11[] = {
  0xab, 0xb5, 0x26, 0x80 // eor hi r11 r6 r11 LSR 11
};
const byte kInstruction_eor_vc_r5_r7_r11_LSR_13[] = {
  0xab, 0x56, 0x27, 0x70 // eor vc r5 r7 r11 LSR 13
};
const byte kInstruction_eor_cc_r13_r9_r9_LSR_21[] = {
  0xa9, 0xda, 0x29, 0x30 // eor cc r13 r9 r9 LSR 21
};
const byte kInstruction_eor_al_r3_r14_r14_ASR_31[] = {
  0xce, 0x3f, 0x2e, 0xe0 // eor al r3 r14 r14 ASR 31
};
const byte kInstruction_eor_ls_r13_r3_r9_LSR_28[] = {
  0x29, 0xde, 0x23, 0x90 // eor ls r13 r3 r9 LSR 28
};
const byte kInstruction_eor_pl_r11_r5_r11_ASR_26[] = {
  0x4b, 0xbd, 0x25, 0x50 // eor pl r11 r5 r11 ASR 26
};
const byte kInstruction_eor_cc_r2_r9_r8_ASR_25[] = {
  0xc8, 0x2c, 0x29, 0x30 // eor cc r2 r9 r8 ASR 25
};
const byte kInstruction_eor_al_r10_r2_r6_ASR_8[] = {
  0x46, 0xa4, 0x22, 0xe0 // eor al r10 r2 r6 ASR 8
};
const byte kInstruction_eor_vc_r12_r9_r2_ASR_15[] = {
  0xc2, 0xc7, 0x29, 0x70 // eor vc r12 r9 r2 ASR 15
};
const byte kInstruction_eor_vs_r7_r9_r8_LSR_13[] = {
  0xa8, 0x76, 0x29, 0x60 // eor vs r7 r9 r8 LSR 13
};
const byte kInstruction_eor_pl_r12_r6_r7_ASR_21[] = {
  0xc7, 0xca, 0x26, 0x50 // eor pl r12 r6 r7 ASR 21
};
const byte kInstruction_eor_eq_r0_r0_r11_ASR_10[] = {
  0x4b, 0x05, 0x20, 0x00 // eor eq r0 r0 r11 ASR 10
};
const byte kInstruction_eor_lt_r1_r12_r9_LSR_8[] = {
  0x29, 0x14, 0x2c, 0xb0 // eor lt r1 r12 r9 LSR 8
};
const byte kInstruction_eor_hi_r14_r14_r8_LSR_4[] = {
  0x28, 0xe2, 0x2e, 0x80 // eor hi r14 r14 r8 LSR 4
};
const byte kInstruction_eor_vs_r10_r12_r14_LSR_14[] = {
  0x2e, 0xa7, 0x2c, 0x60 // eor vs r10 r12 r14 LSR 14
};
const byte kInstruction_eor_lt_r11_r4_r8_ASR_4[] = {
  0x48, 0xb2, 0x24, 0xb0 // eor lt r11 r4 r8 ASR 4
};
const byte kInstruction_eor_hi_r13_r14_r14_LSR_8[] = {
  0x2e, 0xd4, 0x2e, 0x80 // eor hi r13 r14 r14 LSR 8
};
const byte kInstruction_eor_al_r0_r7_r8_ASR_8[] = {
  0x48, 0x04, 0x27, 0xe0 // eor al r0 r7 r8 ASR 8
};
const byte kInstruction_eor_cc_r12_r14_r1_ASR_25[] = {
  0xc1, 0xcc, 0x2e, 0x30 // eor cc r12 r14 r1 ASR 25
};
const byte kInstruction_eor_pl_r12_r0_r2_LSR_4[] = {
  0x22, 0xc2, 0x20, 0x50 // eor pl r12 r0 r2 LSR 4
};
const byte kInstruction_eor_pl_r12_r2_r2_LSR_15[] = {
  0xa2, 0xc7, 0x22, 0x50 // eor pl r12 r2 r2 LSR 15
};
const byte kInstruction_eor_gt_r11_r12_r3_LSR_13[] = {
  0xa3, 0xb6, 0x2c, 0xc0 // eor gt r11 r12 r3 LSR 13
};
const byte kInstruction_eor_al_r2_r7_r6_ASR_19[] = {
  0xc6, 0x29, 0x27, 0xe0 // eor al r2 r7 r6 ASR 19
};
const byte kInstruction_eor_eq_r0_r3_r5_LSR_11[] = {
  0xa5, 0x05, 0x23, 0x00 // eor eq r0 r3 r5 LSR 11
};
const byte kInstruction_eor_mi_r1_r12_r1_LSR_25[] = {
  0xa1, 0x1c, 0x2c, 0x40 // eor mi r1 r12 r1 LSR 25
};
const byte kInstruction_eor_hi_r2_r7_r2_LSR_20[] = {
  0x22, 0x2a, 0x27, 0x80 // eor hi r2 r7 r2 LSR 20
};
const byte kInstruction_eor_gt_r14_r12_r2_LSR_2[] = {
  0x22, 0xe1, 0x2c, 0xc0 // eor gt r14 r12 r2 LSR 2
};
const byte kInstruction_eor_gt_r1_r13_r4_LSR_15[] = {
  0xa4, 0x17, 0x2d, 0xc0 // eor gt r1 r13 r4 LSR 15
};
const byte kInstruction_eor_lt_r11_r4_r12_ASR_11[] = {
  0xcc, 0xb5, 0x24, 0xb0 // eor lt r11 r4 r12 ASR 11
};
const byte kInstruction_eor_cs_r0_r0_r14_LSR_26[] = {
  0x2e, 0x0d, 0x20, 0x20 // eor cs r0 r0 r14 LSR 26
};
const byte kInstruction_eor_lt_r12_r6_r0_LSR_22[] = {
  0x20, 0xcb, 0x26, 0xb0 // eor lt r12 r6 r0 LSR 22
};
const byte kInstruction_eor_al_r11_r8_r2_ASR_9[] = {
  0xc2, 0xb4, 0x28, 0xe0 // eor al r11 r8 r2 ASR 9
};
const byte kInstruction_eor_ls_r8_r10_r3_ASR_17[] = {
  0xc3, 0x88, 0x2a, 0x90 // eor ls r8 r10 r3 ASR 17
};
const byte kInstruction_eor_hi_r7_r2_r14_LSR_13[] = {
  0xae, 0x76, 0x22, 0x80 // eor hi r7 r2 r14 LSR 13
};
const byte kInstruction_eor_hi_r13_r10_r12_ASR_31[] = {
  0xcc, 0xdf, 0x2a, 0x80 // eor hi r13 r10 r12 ASR 31
};
const byte kInstruction_eor_cs_r1_r5_r10_ASR_29[] = {
  0xca, 0x1e, 0x25, 0x20 // eor cs r1 r5 r10 ASR 29
};
const byte kInstruction_eor_lt_r11_r11_r9_LSR_18[] = {
  0x29, 0xb9, 0x2b, 0xb0 // eor lt r11 r11 r9 LSR 18
};
const byte kInstruction_eor_gt_r3_r4_r4_LSR_1[] = {
  0xa4, 0x30, 0x24, 0xc0 // eor gt r3 r4 r4 LSR 1
};
const byte kInstruction_eor_ge_r10_r12_r4_LSR_12[] = {
  0x24, 0xa6, 0x2c, 0xa0 // eor ge r10 r12 r4 LSR 12
};
const byte kInstruction_eor_hi_r4_r13_r11_ASR_25[] = {
  0xcb, 0x4c, 0x2d, 0x80 // eor hi r4 r13 r11 ASR 25
};
const byte kInstruction_eor_le_r0_r8_r4_ASR_4[] = {
  0x44, 0x02, 0x28, 0xd0 // eor le r0 r8 r4 ASR 4
};
const byte kInstruction_eor_mi_r14_r14_r3_LSR_31[] = {
  0xa3, 0xef, 0x2e, 0x40 // eor mi r14 r14 r3 LSR 31
};
const byte kInstruction_eor_gt_r7_r4_r8_ASR_15[] = {
  0xc8, 0x77, 0x24, 0xc0 // eor gt r7 r4 r8 ASR 15
};
const byte kInstruction_eor_eq_r4_r6_r6_ASR_1[] = {
  0xc6, 0x40, 0x26, 0x00 // eor eq r4 r6 r6 ASR 1
};
const byte kInstruction_eor_vs_r13_r2_r6_ASR_30[] = {
  0x46, 0xdf, 0x22, 0x60 // eor vs r13 r2 r6 ASR 30
};
const TestResult kReferenceeor[] = {
  {
    ARRAY_SIZE(kInstruction_eor_eq_r13_r6_r7_ASR_5),
    kInstruction_eor_eq_r13_r6_r7_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r8_r11_r8_ASR_32),
    kInstruction_eor_mi_r8_r11_r8_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r2_r3_r10_ASR_18),
    kInstruction_eor_hi_r2_r3_r10_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r13_r8_r14_LSR_32),
    kInstruction_eor_ls_r13_r8_r14_LSR_32,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r8_r9_r2_ASR_3),
    kInstruction_eor_cc_r8_r9_r2_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r14_r2_r5_LSR_2),
    kInstruction_eor_ls_r14_r2_r5_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r8_r6_r1_ASR_31),
    kInstruction_eor_pl_r8_r6_r1_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r2_r0_r14_LSR_3),
    kInstruction_eor_le_r2_r0_r14_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r2_r0_r13_LSR_15),
    kInstruction_eor_ne_r2_r0_r13_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r9_r12_r3_LSR_8),
    kInstruction_eor_ge_r9_r12_r3_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r13_r8_r1_ASR_7),
    kInstruction_eor_pl_r13_r8_r1_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r10_r13_r4_LSR_5),
    kInstruction_eor_cs_r10_r13_r4_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r13_r8_r11_ASR_17),
    kInstruction_eor_pl_r13_r8_r11_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r8_r7_r3_LSR_9),
    kInstruction_eor_cs_r8_r7_r3_LSR_9,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r11_r2_r7_LSR_30),
    kInstruction_eor_vc_r11_r2_r7_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r6_r14_r7_LSR_19),
    kInstruction_eor_ge_r6_r14_r7_LSR_19,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r11_r3_r0_LSR_20),
    kInstruction_eor_cc_r11_r3_r0_LSR_20,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r10_r9_r7_ASR_25),
    kInstruction_eor_lt_r10_r9_r7_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r8_r0_r12_LSR_30),
    kInstruction_eor_ne_r8_r0_r12_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r1_r4_r13_ASR_32),
    kInstruction_eor_vc_r1_r4_r13_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r8_r14_r8_LSR_14),
    kInstruction_eor_al_r8_r14_r8_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r2_r12_r7_ASR_2),
    kInstruction_eor_pl_r2_r12_r7_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r11_r1_r0_LSR_14),
    kInstruction_eor_pl_r11_r1_r0_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r5_r11_r9_ASR_24),
    kInstruction_eor_gt_r5_r11_r9_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r8_r9_r12_ASR_6),
    kInstruction_eor_eq_r8_r9_r12_ASR_6,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r10_r9_r12_LSR_30),
    kInstruction_eor_cs_r10_r9_r12_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r7_r11_r2_ASR_21),
    kInstruction_eor_lt_r7_r11_r2_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r14_r3_r11_LSR_10),
    kInstruction_eor_eq_r14_r3_r11_LSR_10,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r4_r11_r5_ASR_7),
    kInstruction_eor_vs_r4_r11_r5_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r7_r14_r12_ASR_3),
    kInstruction_eor_le_r7_r14_r12_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r7_r4_r0_ASR_17),
    kInstruction_eor_ne_r7_r4_r0_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r5_r11_r3_ASR_4),
    kInstruction_eor_hi_r5_r11_r3_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r8_r7_r9_LSR_24),
    kInstruction_eor_cs_r8_r7_r9_LSR_24,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r3_r9_r13_LSR_7),
    kInstruction_eor_vc_r3_r9_r13_LSR_7,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r6_r14_r3_LSR_2),
    kInstruction_eor_lt_r6_r14_r3_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r10_r14_r2_LSR_29),
    kInstruction_eor_lt_r10_r14_r2_LSR_29,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r8_r12_r0_ASR_30),
    kInstruction_eor_mi_r8_r12_r0_ASR_30,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r9_r0_r5_LSR_25),
    kInstruction_eor_ls_r9_r0_r5_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r10_r12_r5_ASR_21),
    kInstruction_eor_ls_r10_r12_r5_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r9_r10_r0_LSR_8),
    kInstruction_eor_vs_r9_r10_r0_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r13_r9_r9_LSR_32),
    kInstruction_eor_mi_r13_r9_r9_LSR_32,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r10_r14_r4_ASR_5),
    kInstruction_eor_mi_r10_r14_r4_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r12_r2_r12_LSR_7),
    kInstruction_eor_ls_r12_r2_r12_LSR_7,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r5_r5_r11_LSR_20),
    kInstruction_eor_ne_r5_r5_r11_LSR_20,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r5_r2_r13_ASR_15),
    kInstruction_eor_vc_r5_r2_r13_ASR_15,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r8_r13_r0_LSR_2),
    kInstruction_eor_cc_r8_r13_r0_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r5_r5_r12_LSR_9),
    kInstruction_eor_hi_r5_r5_r12_LSR_9,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r9_r10_r5_ASR_29),
    kInstruction_eor_cs_r9_r10_r5_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r14_r1_r2_ASR_10),
    kInstruction_eor_le_r14_r1_r2_ASR_10,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r1_r11_r5_LSR_23),
    kInstruction_eor_mi_r1_r11_r5_LSR_23,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r3_r0_r12_LSR_9),
    kInstruction_eor_vc_r3_r0_r12_LSR_9,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r2_r4_r11_LSR_14),
    kInstruction_eor_cs_r2_r4_r11_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r8_r13_r2_ASR_29),
    kInstruction_eor_gt_r8_r13_r2_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r1_r8_r13_ASR_9),
    kInstruction_eor_vc_r1_r8_r13_ASR_9,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r3_r10_r6_LSR_29),
    kInstruction_eor_vs_r3_r10_r6_LSR_29,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r1_r3_r6_LSR_6),
    kInstruction_eor_ge_r1_r3_r6_LSR_6,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r5_r1_r9_ASR_4),
    kInstruction_eor_cs_r5_r1_r9_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r3_r6_r14_ASR_22),
    kInstruction_eor_le_r3_r6_r14_ASR_22,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r4_r4_r9_LSR_15),
    kInstruction_eor_le_r4_r4_r9_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r13_r3_r1_LSR_25),
    kInstruction_eor_le_r13_r3_r1_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r8_r14_r8_ASR_5),
    kInstruction_eor_cc_r8_r14_r8_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r6_r12_r0_ASR_14),
    kInstruction_eor_ge_r6_r12_r0_ASR_14,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r3_r6_r10_LSR_15),
    kInstruction_eor_gt_r3_r6_r10_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r0_r5_r6_LSR_29),
    kInstruction_eor_cs_r0_r5_r6_LSR_29,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r6_r4_r3_LSR_13),
    kInstruction_eor_pl_r6_r4_r3_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r8_r12_r6_LSR_5),
    kInstruction_eor_pl_r8_r12_r6_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r13_r7_r0_LSR_18),
    kInstruction_eor_vc_r13_r7_r0_LSR_18,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r0_r12_r8_ASR_1),
    kInstruction_eor_ne_r0_r12_r8_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r8_r2_r10_ASR_14),
    kInstruction_eor_ls_r8_r2_r10_ASR_14,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r5_r3_r9_ASR_2),
    kInstruction_eor_al_r5_r3_r9_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r1_r14_r13_LSR_4),
    kInstruction_eor_vc_r1_r14_r13_LSR_4,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r0_r10_r4_LSR_30),
    kInstruction_eor_vc_r0_r10_r4_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r3_r0_r11_ASR_14),
    kInstruction_eor_al_r3_r0_r11_ASR_14,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r3_r11_r10_ASR_23),
    kInstruction_eor_vs_r3_r11_r10_ASR_23,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r0_r9_r0_ASR_8),
    kInstruction_eor_ls_r0_r9_r0_ASR_8,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r2_r8_r10_LSR_5),
    kInstruction_eor_le_r2_r8_r10_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r0_r5_r0_LSR_31),
    kInstruction_eor_cs_r0_r5_r0_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r1_r10_r13_LSR_27),
    kInstruction_eor_cc_r1_r10_r13_LSR_27,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r11_r13_r12_ASR_17),
    kInstruction_eor_ge_r11_r13_r12_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r2_r9_r4_LSR_12),
    kInstruction_eor_eq_r2_r9_r4_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r4_r14_r0_ASR_13),
    kInstruction_eor_ge_r4_r14_r0_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r1_r6_r0_ASR_16),
    kInstruction_eor_vc_r1_r6_r0_ASR_16,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r7_r9_r12_LSR_11),
    kInstruction_eor_hi_r7_r9_r12_LSR_11,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r14_r11_r12_LSR_29),
    kInstruction_eor_eq_r14_r11_r12_LSR_29,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r14_r13_r4_ASR_23),
    kInstruction_eor_ge_r14_r13_r4_ASR_23,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r8_r0_r14_ASR_25),
    kInstruction_eor_pl_r8_r0_r14_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r7_r13_r12_LSR_14),
    kInstruction_eor_ne_r7_r13_r12_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r13_r4_r7_ASR_10),
    kInstruction_eor_vs_r13_r4_r7_ASR_10,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r3_r14_r9_ASR_15),
    kInstruction_eor_mi_r3_r14_r9_ASR_15,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r14_r9_r14_ASR_25),
    kInstruction_eor_cs_r14_r9_r14_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r11_r7_r4_LSR_4),
    kInstruction_eor_cc_r11_r7_r4_LSR_4,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r11_r7_r2_ASR_1),
    kInstruction_eor_cc_r11_r7_r2_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r0_r5_r5_LSR_11),
    kInstruction_eor_al_r0_r5_r5_LSR_11,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r3_r5_r13_LSR_3),
    kInstruction_eor_eq_r3_r5_r13_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r11_r1_r1_ASR_24),
    kInstruction_eor_ge_r11_r1_r1_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r13_r12_r12_LSR_9),
    kInstruction_eor_lt_r13_r12_r12_LSR_9,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r13_r1_r14_LSR_26),
    kInstruction_eor_cs_r13_r1_r14_LSR_26,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r10_r4_r4_LSR_31),
    kInstruction_eor_ge_r10_r4_r4_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r7_r7_r5_ASR_5),
    kInstruction_eor_pl_r7_r7_r5_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r2_r13_r10_ASR_26),
    kInstruction_eor_eq_r2_r13_r10_ASR_26,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r5_r8_r13_LSR_23),
    kInstruction_eor_ne_r5_r8_r13_LSR_23,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r0_r5_r12_LSR_1),
    kInstruction_eor_al_r0_r5_r12_LSR_1,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r10_r11_r4_ASR_23),
    kInstruction_eor_al_r10_r11_r4_ASR_23,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r0_r11_r10_LSR_1),
    kInstruction_eor_al_r0_r11_r10_LSR_1,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r9_r9_r2_LSR_18),
    kInstruction_eor_eq_r9_r9_r2_LSR_18,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r2_r9_r8_ASR_25),
    kInstruction_eor_mi_r2_r9_r8_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r6_r7_r1_LSR_3),
    kInstruction_eor_vc_r6_r7_r1_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r6_r10_r0_ASR_29),
    kInstruction_eor_pl_r6_r10_r0_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r9_r5_r5_ASR_10),
    kInstruction_eor_gt_r9_r5_r5_ASR_10,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r1_r0_r3_LSR_28),
    kInstruction_eor_mi_r1_r0_r3_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r10_r11_r9_LSR_8),
    kInstruction_eor_ne_r10_r11_r9_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r1_r9_r3_ASR_29),
    kInstruction_eor_ls_r1_r9_r3_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r13_r10_r13_LSR_9),
    kInstruction_eor_eq_r13_r10_r13_LSR_9,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r13_r0_r3_ASR_20),
    kInstruction_eor_mi_r13_r0_r3_ASR_20,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r14_r13_r12_ASR_18),
    kInstruction_eor_eq_r14_r13_r12_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r10_r7_r6_ASR_2),
    kInstruction_eor_mi_r10_r7_r6_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r0_r1_r2_LSR_32),
    kInstruction_eor_hi_r0_r1_r2_LSR_32,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r10_r2_r8_LSR_14),
    kInstruction_eor_pl_r10_r2_r8_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r12_r6_r2_ASR_8),
    kInstruction_eor_le_r12_r6_r2_ASR_8,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r4_r0_r4_ASR_12),
    kInstruction_eor_gt_r4_r0_r4_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r9_r0_r10_LSR_15),
    kInstruction_eor_eq_r9_r0_r10_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r7_r1_r8_ASR_8),
    kInstruction_eor_ge_r7_r1_r8_ASR_8,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r1_r1_r12_ASR_7),
    kInstruction_eor_al_r1_r1_r12_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r13_r1_r2_LSR_11),
    kInstruction_eor_lt_r13_r1_r2_LSR_11,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r2_r5_r3_ASR_3),
    kInstruction_eor_cc_r2_r5_r3_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r8_r2_r9_LSR_14),
    kInstruction_eor_ne_r8_r2_r9_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r11_r8_r1_LSR_3),
    kInstruction_eor_eq_r11_r8_r1_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r3_r14_r11_LSR_14),
    kInstruction_eor_al_r3_r14_r11_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r1_r2_r7_LSR_31),
    kInstruction_eor_pl_r1_r2_r7_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r14_r2_r5_LSR_20),
    kInstruction_eor_eq_r14_r2_r5_LSR_20,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r7_r13_r3_LSR_21),
    kInstruction_eor_hi_r7_r13_r3_LSR_21,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r14_r7_r11_LSR_16),
    kInstruction_eor_gt_r14_r7_r11_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r0_r5_r14_ASR_25),
    kInstruction_eor_ls_r0_r5_r14_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r0_r7_r8_LSR_4),
    kInstruction_eor_cc_r0_r7_r8_LSR_4,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r3_r5_r9_ASR_9),
    kInstruction_eor_hi_r3_r5_r9_ASR_9,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r10_r5_r5_ASR_15),
    kInstruction_eor_hi_r10_r5_r5_ASR_15,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r7_r14_r0_LSR_19),
    kInstruction_eor_le_r7_r14_r0_LSR_19,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r10_r1_r2_LSR_16),
    kInstruction_eor_gt_r10_r1_r2_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r4_r14_r10_LSR_21),
    kInstruction_eor_ls_r4_r14_r10_LSR_21,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r12_r14_r3_LSR_11),
    kInstruction_eor_mi_r12_r14_r3_LSR_11,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r7_r9_r4_LSR_12),
    kInstruction_eor_al_r7_r9_r4_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r0_r10_r1_ASR_20),
    kInstruction_eor_cc_r0_r10_r1_ASR_20,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r0_r2_r11_LSR_31),
    kInstruction_eor_mi_r0_r2_r11_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r7_r9_r6_ASR_22),
    kInstruction_eor_cs_r7_r9_r6_ASR_22,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r9_r6_r13_LSR_25),
    kInstruction_eor_gt_r9_r6_r13_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r1_r2_r8_ASR_16),
    kInstruction_eor_cc_r1_r2_r8_ASR_16,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r6_r4_r14_ASR_12),
    kInstruction_eor_ne_r6_r4_r14_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r7_r2_r14_ASR_11),
    kInstruction_eor_al_r7_r2_r14_ASR_11,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r10_r14_r13_LSR_22),
    kInstruction_eor_gt_r10_r14_r13_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r0_r8_r6_LSR_25),
    kInstruction_eor_lt_r0_r8_r6_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r12_r5_r6_ASR_20),
    kInstruction_eor_ne_r12_r5_r6_ASR_20,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r12_r6_r7_ASR_27),
    kInstruction_eor_pl_r12_r6_r7_ASR_27,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r5_r8_r7_ASR_19),
    kInstruction_eor_gt_r5_r8_r7_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r12_r1_r4_LSR_22),
    kInstruction_eor_le_r12_r1_r4_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r9_r8_r11_LSR_17),
    kInstruction_eor_le_r9_r8_r11_LSR_17,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r5_r2_r3_ASR_30),
    kInstruction_eor_gt_r5_r2_r3_ASR_30,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r8_r7_r7_ASR_31),
    kInstruction_eor_ge_r8_r7_r7_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r14_r8_r11_ASR_23),
    kInstruction_eor_lt_r14_r8_r11_ASR_23,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r0_r11_r6_LSR_1),
    kInstruction_eor_cc_r0_r11_r6_LSR_1,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r0_r6_r14_LSR_2),
    kInstruction_eor_pl_r0_r6_r14_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r4_r2_r1_ASR_16),
    kInstruction_eor_lt_r4_r2_r1_ASR_16,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r14_r2_r14_ASR_19),
    kInstruction_eor_pl_r14_r2_r14_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r13_r5_r9_LSR_32),
    kInstruction_eor_cs_r13_r5_r9_LSR_32,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r13_r8_r1_LSR_1),
    kInstruction_eor_cc_r13_r8_r1_LSR_1,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r7_r9_r10_LSR_17),
    kInstruction_eor_cs_r7_r9_r10_LSR_17,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r2_r1_r7_LSR_29),
    kInstruction_eor_vc_r2_r1_r7_LSR_29,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r9_r2_r1_ASR_17),
    kInstruction_eor_hi_r9_r2_r1_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r14_r14_r7_ASR_17),
    kInstruction_eor_cc_r14_r14_r7_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r4_r8_r1_LSR_17),
    kInstruction_eor_vs_r4_r8_r1_LSR_17,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r8_r0_r6_LSR_8),
    kInstruction_eor_vs_r8_r0_r6_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r8_r0_r14_LSR_12),
    kInstruction_eor_vs_r8_r0_r14_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r5_r8_r1_ASR_10),
    kInstruction_eor_vc_r5_r8_r1_ASR_10,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r2_r0_r5_ASR_12),
    kInstruction_eor_eq_r2_r0_r5_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r13_r2_r11_LSR_27),
    kInstruction_eor_vc_r13_r2_r11_LSR_27,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r9_r3_r1_LSR_15),
    kInstruction_eor_vc_r9_r3_r1_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r3_r11_r10_ASR_19),
    kInstruction_eor_gt_r3_r11_r10_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r1_r0_r6_ASR_23),
    kInstruction_eor_pl_r1_r0_r6_ASR_23,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r3_r7_r8_LSR_8),
    kInstruction_eor_ls_r3_r7_r8_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r12_r14_r11_LSR_22),
    kInstruction_eor_ls_r12_r14_r11_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r5_r3_r8_ASR_6),
    kInstruction_eor_vc_r5_r3_r8_ASR_6,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r4_r13_r14_LSR_10),
    kInstruction_eor_le_r4_r13_r14_LSR_10,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r7_r4_r14_ASR_8),
    kInstruction_eor_vc_r7_r4_r14_ASR_8,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r3_r7_r8_LSR_3),
    kInstruction_eor_ge_r3_r7_r8_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r13_r8_r4_LSR_18),
    kInstruction_eor_al_r13_r8_r4_LSR_18,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r7_r0_r6_ASR_21),
    kInstruction_eor_gt_r7_r0_r6_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r3_r11_r13_LSR_31),
    kInstruction_eor_al_r3_r11_r13_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r5_r0_r11_ASR_6),
    kInstruction_eor_le_r5_r0_r11_ASR_6,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r11_r2_r5_LSR_26),
    kInstruction_eor_cc_r11_r2_r5_LSR_26,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r10_r14_r7_ASR_8),
    kInstruction_eor_eq_r10_r14_r7_ASR_8,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r0_r0_r5_LSR_3),
    kInstruction_eor_ne_r0_r0_r5_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r9_r1_r2_ASR_6),
    kInstruction_eor_mi_r9_r1_r2_ASR_6,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r6_r10_r13_ASR_17),
    kInstruction_eor_eq_r6_r10_r13_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r2_r7_r0_ASR_32),
    kInstruction_eor_hi_r2_r7_r0_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r14_r3_r11_LSR_17),
    kInstruction_eor_ge_r14_r3_r11_LSR_17,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r6_r4_r5_LSR_4),
    kInstruction_eor_cc_r6_r4_r5_LSR_4,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r9_r14_r3_LSR_32),
    kInstruction_eor_al_r9_r14_r3_LSR_32,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r14_r14_r6_LSR_23),
    kInstruction_eor_vc_r14_r14_r6_LSR_23,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r1_r9_r7_ASR_6),
    kInstruction_eor_le_r1_r9_r7_ASR_6,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r2_r11_r7_ASR_5),
    kInstruction_eor_mi_r2_r11_r7_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r3_r14_r9_LSR_25),
    kInstruction_eor_le_r3_r14_r9_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r10_r8_r10_ASR_25),
    kInstruction_eor_mi_r10_r8_r10_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r5_r9_r5_LSR_24),
    kInstruction_eor_eq_r5_r9_r5_LSR_24,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r2_r3_r13_ASR_24),
    kInstruction_eor_al_r2_r3_r13_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r6_r3_r7_ASR_23),
    kInstruction_eor_cc_r6_r3_r7_ASR_23,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r11_r11_r13_LSR_7),
    kInstruction_eor_ge_r11_r11_r13_LSR_7,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r14_r1_r3_ASR_17),
    kInstruction_eor_vc_r14_r1_r3_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r5_r1_r14_ASR_3),
    kInstruction_eor_ls_r5_r1_r14_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r13_r5_r4_LSR_18),
    kInstruction_eor_ge_r13_r5_r4_LSR_18,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r6_r5_r14_LSR_6),
    kInstruction_eor_gt_r6_r5_r14_LSR_6,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r9_r6_r7_LSR_11),
    kInstruction_eor_eq_r9_r6_r7_LSR_11,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r14_r6_r12_ASR_27),
    kInstruction_eor_eq_r14_r6_r12_ASR_27,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r14_r14_r9_ASR_19),
    kInstruction_eor_pl_r14_r14_r9_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r14_r12_r8_LSR_13),
    kInstruction_eor_le_r14_r12_r8_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r7_r5_r5_LSR_13),
    kInstruction_eor_cc_r7_r5_r5_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r2_r13_r4_ASR_19),
    kInstruction_eor_eq_r2_r13_r4_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r11_r11_r10_ASR_2),
    kInstruction_eor_vs_r11_r11_r10_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r10_r8_r8_LSR_23),
    kInstruction_eor_cc_r10_r8_r8_LSR_23,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r14_r12_r6_ASR_30),
    kInstruction_eor_ls_r14_r12_r6_ASR_30,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r8_r8_r6_ASR_19),
    kInstruction_eor_hi_r8_r8_r6_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r5_r12_r3_ASR_6),
    kInstruction_eor_cs_r5_r12_r3_ASR_6,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r0_r9_r14_ASR_5),
    kInstruction_eor_vs_r0_r9_r14_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r9_r6_r14_ASR_7),
    kInstruction_eor_lt_r9_r6_r14_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r5_r1_r11_ASR_3),
    kInstruction_eor_lt_r5_r1_r11_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r4_r11_r3_LSR_14),
    kInstruction_eor_al_r4_r11_r3_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r7_r1_r3_LSR_10),
    kInstruction_eor_cs_r7_r1_r3_LSR_10,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r2_r11_r4_ASR_29),
    kInstruction_eor_cc_r2_r11_r4_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r7_r1_r4_LSR_31),
    kInstruction_eor_eq_r7_r1_r4_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r2_r13_r7_ASR_17),
    kInstruction_eor_hi_r2_r13_r7_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r12_r10_r9_ASR_4),
    kInstruction_eor_cs_r12_r10_r9_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r10_r2_r2_LSR_28),
    kInstruction_eor_gt_r10_r2_r2_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r13_r12_r0_ASR_2),
    kInstruction_eor_gt_r13_r12_r0_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r14_r8_r7_LSR_1),
    kInstruction_eor_pl_r14_r8_r7_LSR_1,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r2_r13_r3_ASR_20),
    kInstruction_eor_hi_r2_r13_r3_ASR_20,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r2_r3_r3_LSR_13),
    kInstruction_eor_lt_r2_r3_r3_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r11_r1_r12_ASR_24),
    kInstruction_eor_mi_r11_r1_r12_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r8_r8_r8_LSR_1),
    kInstruction_eor_vs_r8_r8_r8_LSR_1,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r2_r14_r3_ASR_31),
    kInstruction_eor_ne_r2_r14_r3_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r8_r5_r1_LSR_11),
    kInstruction_eor_lt_r8_r5_r1_LSR_11,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r4_r9_r8_ASR_31),
    kInstruction_eor_pl_r4_r9_r8_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r8_r1_r13_ASR_4),
    kInstruction_eor_ls_r8_r1_r13_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r2_r9_r14_LSR_16),
    kInstruction_eor_al_r2_r9_r14_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r3_r6_r10_ASR_5),
    kInstruction_eor_cs_r3_r6_r10_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r4_r12_r6_ASR_9),
    kInstruction_eor_eq_r4_r12_r6_ASR_9,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r12_r12_r4_ASR_32),
    kInstruction_eor_al_r12_r12_r4_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r1_r6_r11_LSR_19),
    kInstruction_eor_pl_r1_r6_r11_LSR_19,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r8_r2_r1_LSR_13),
    kInstruction_eor_pl_r8_r2_r1_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r2_r11_r2_LSR_23),
    kInstruction_eor_gt_r2_r11_r2_LSR_23,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r14_r8_r6_ASR_31),
    kInstruction_eor_eq_r14_r8_r6_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r6_r5_r7_ASR_31),
    kInstruction_eor_cc_r6_r5_r7_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r14_r10_r11_ASR_28),
    kInstruction_eor_cs_r14_r10_r11_ASR_28,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r9_r9_r4_LSR_22),
    kInstruction_eor_le_r9_r9_r4_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r4_r1_r14_ASR_11),
    kInstruction_eor_cs_r4_r1_r14_ASR_11,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r6_r0_r9_LSR_30),
    kInstruction_eor_ne_r6_r0_r9_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r8_r6_r6_ASR_16),
    kInstruction_eor_gt_r8_r6_r6_ASR_16,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r11_r3_r5_ASR_4),
    kInstruction_eor_pl_r11_r3_r5_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r6_r3_r5_LSR_20),
    kInstruction_eor_cs_r6_r3_r5_LSR_20,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r1_r9_r13_LSR_26),
    kInstruction_eor_cc_r1_r9_r13_LSR_26,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r5_r11_r2_ASR_14),
    kInstruction_eor_vc_r5_r11_r2_ASR_14,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r11_r0_r0_ASR_12),
    kInstruction_eor_vc_r11_r0_r0_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r3_r8_r2_LSR_7),
    kInstruction_eor_mi_r3_r8_r2_LSR_7,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r11_r2_r11_ASR_32),
    kInstruction_eor_eq_r11_r2_r11_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r6_r0_r9_LSR_5),
    kInstruction_eor_vc_r6_r0_r9_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r4_r10_r13_LSR_15),
    kInstruction_eor_gt_r4_r10_r13_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r5_r13_r14_LSR_30),
    kInstruction_eor_mi_r5_r13_r14_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r2_r13_r12_LSR_12),
    kInstruction_eor_ge_r2_r13_r12_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r0_r3_r2_LSR_2),
    kInstruction_eor_ge_r0_r3_r2_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r12_r10_r0_LSR_7),
    kInstruction_eor_lt_r12_r10_r0_LSR_7,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r11_r8_r0_LSR_15),
    kInstruction_eor_hi_r11_r8_r0_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r9_r10_r5_LSR_31),
    kInstruction_eor_le_r9_r10_r5_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r5_r3_r3_LSR_5),
    kInstruction_eor_cs_r5_r3_r3_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r8_r0_r4_ASR_1),
    kInstruction_eor_mi_r8_r0_r4_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r2_r6_r10_ASR_22),
    kInstruction_eor_lt_r2_r6_r10_ASR_22,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r8_r4_r12_ASR_22),
    kInstruction_eor_cc_r8_r4_r12_ASR_22,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r10_r0_r12_ASR_21),
    kInstruction_eor_vc_r10_r0_r12_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r14_r8_r9_ASR_26),
    kInstruction_eor_mi_r14_r8_r9_ASR_26,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r2_r4_r9_LSR_23),
    kInstruction_eor_al_r2_r4_r9_LSR_23,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r3_r0_r0_ASR_22),
    kInstruction_eor_mi_r3_r0_r0_ASR_22,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r6_r0_r7_ASR_8),
    kInstruction_eor_ge_r6_r0_r7_ASR_8,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r7_r14_r8_ASR_23),
    kInstruction_eor_ls_r7_r14_r8_ASR_23,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r6_r5_r12_LSR_30),
    kInstruction_eor_ne_r6_r5_r12_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r5_r1_r3_ASR_29),
    kInstruction_eor_ge_r5_r1_r3_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r2_r10_r2_ASR_17),
    kInstruction_eor_cc_r2_r10_r2_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r6_r4_r3_LSR_2),
    kInstruction_eor_ne_r6_r4_r3_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r10_r13_r11_LSR_19),
    kInstruction_eor_vs_r10_r13_r11_LSR_19,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r0_r0_r8_LSR_27),
    kInstruction_eor_hi_r0_r0_r8_LSR_27,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r4_r3_r9_LSR_16),
    kInstruction_eor_gt_r4_r3_r9_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r13_r11_r1_LSR_21),
    kInstruction_eor_lt_r13_r11_r1_LSR_21,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r13_r10_r2_LSR_30),
    kInstruction_eor_mi_r13_r10_r2_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r4_r13_r2_LSR_19),
    kInstruction_eor_mi_r4_r13_r2_LSR_19,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r6_r3_r5_LSR_8),
    kInstruction_eor_vs_r6_r3_r5_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r9_r12_r9_ASR_28),
    kInstruction_eor_ls_r9_r12_r9_ASR_28,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r1_r2_r2_ASR_3),
    kInstruction_eor_al_r1_r2_r2_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r11_r11_r3_LSR_2),
    kInstruction_eor_ls_r11_r11_r3_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r10_r3_r5_LSR_2),
    kInstruction_eor_al_r10_r3_r5_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r1_r11_r1_LSR_14),
    kInstruction_eor_eq_r1_r11_r1_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r0_r1_r4_ASR_12),
    kInstruction_eor_mi_r0_r1_r4_ASR_12,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r0_r3_r0_LSR_5),
    kInstruction_eor_pl_r0_r3_r0_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r2_r2_r8_LSR_27),
    kInstruction_eor_mi_r2_r2_r8_LSR_27,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r13_r1_r13_LSR_20),
    kInstruction_eor_ls_r13_r1_r13_LSR_20,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r1_r4_r1_ASR_5),
    kInstruction_eor_cs_r1_r4_r1_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r5_r9_r1_ASR_6),
    kInstruction_eor_ge_r5_r9_r1_ASR_6,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r7_r8_r11_LSR_30),
    kInstruction_eor_cc_r7_r8_r11_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r1_r10_r8_LSR_12),
    kInstruction_eor_le_r1_r10_r8_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r5_r5_r9_LSR_6),
    kInstruction_eor_gt_r5_r5_r9_LSR_6,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r14_r11_r13_LSR_21),
    kInstruction_eor_eq_r14_r11_r13_LSR_21,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r4_r10_r7_ASR_29),
    kInstruction_eor_hi_r4_r10_r7_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r12_r6_r13_LSR_30),
    kInstruction_eor_ls_r12_r6_r13_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r1_r2_r13_ASR_31),
    kInstruction_eor_cc_r1_r2_r13_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r4_r12_r12_ASR_31),
    kInstruction_eor_cs_r4_r12_r12_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r10_r8_r8_LSR_25),
    kInstruction_eor_cs_r10_r8_r8_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r11_r14_r12_ASR_9),
    kInstruction_eor_eq_r11_r14_r12_ASR_9,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r8_r7_r6_LSR_29),
    kInstruction_eor_pl_r8_r7_r6_LSR_29,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r2_r3_r12_ASR_15),
    kInstruction_eor_vs_r2_r3_r12_ASR_15,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r10_r11_r9_ASR_31),
    kInstruction_eor_vs_r10_r11_r9_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r2_r4_r13_ASR_2),
    kInstruction_eor_mi_r2_r4_r13_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r3_r0_r1_LSR_25),
    kInstruction_eor_ls_r3_r0_r1_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r7_r2_r12_LSR_16),
    kInstruction_eor_pl_r7_r2_r12_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r6_r14_r9_ASR_30),
    kInstruction_eor_ge_r6_r14_r9_ASR_30,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r2_r5_r4_ASR_11),
    kInstruction_eor_pl_r2_r5_r4_ASR_11,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r5_r10_r11_ASR_23),
    kInstruction_eor_al_r5_r10_r11_ASR_23,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r4_r1_r9_LSR_28),
    kInstruction_eor_le_r4_r1_r9_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r13_r4_r2_ASR_25),
    kInstruction_eor_cc_r13_r4_r2_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r7_r7_r8_LSR_9),
    kInstruction_eor_pl_r7_r7_r8_LSR_9,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r8_r11_r0_ASR_13),
    kInstruction_eor_le_r8_r11_r0_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r11_r9_r12_ASR_32),
    kInstruction_eor_eq_r11_r9_r12_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r4_r0_r10_ASR_31),
    kInstruction_eor_ls_r4_r0_r10_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r10_r8_r4_LSR_22),
    kInstruction_eor_gt_r10_r8_r4_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r9_r8_r0_ASR_21),
    kInstruction_eor_ne_r9_r8_r0_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r11_r9_r9_ASR_27),
    kInstruction_eor_lt_r11_r9_r9_ASR_27,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r14_r6_r14_LSR_22),
    kInstruction_eor_vc_r14_r6_r14_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r12_r4_r14_LSR_12),
    kInstruction_eor_vs_r12_r4_r14_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r7_r11_r6_ASR_9),
    kInstruction_eor_lt_r7_r11_r6_ASR_9,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r3_r13_r5_LSR_8),
    kInstruction_eor_lt_r3_r13_r5_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r2_r7_r6_ASR_11),
    kInstruction_eor_le_r2_r7_r6_ASR_11,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r2_r0_r4_ASR_25),
    kInstruction_eor_vc_r2_r0_r4_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r2_r11_r10_LSR_10),
    kInstruction_eor_lt_r2_r11_r10_LSR_10,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r7_r9_r12_ASR_13),
    kInstruction_eor_al_r7_r9_r12_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r13_r0_r2_LSR_2),
    kInstruction_eor_cs_r13_r0_r2_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r0_r6_r0_LSR_23),
    kInstruction_eor_cc_r0_r6_r0_LSR_23,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r10_r2_r12_LSR_21),
    kInstruction_eor_vc_r10_r2_r12_LSR_21,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r0_r1_r6_ASR_28),
    kInstruction_eor_mi_r0_r1_r6_ASR_28,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r0_r12_r1_LSR_23),
    kInstruction_eor_hi_r0_r12_r1_LSR_23,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r10_r7_r3_ASR_6),
    kInstruction_eor_eq_r10_r7_r3_ASR_6,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r9_r13_r9_ASR_9),
    kInstruction_eor_hi_r9_r13_r9_ASR_9,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r4_r14_r1_LSR_13),
    kInstruction_eor_le_r4_r14_r1_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r9_r12_r12_LSR_2),
    kInstruction_eor_vs_r9_r12_r12_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r11_r3_r4_ASR_7),
    kInstruction_eor_vc_r11_r3_r4_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r13_r8_r3_LSR_8),
    kInstruction_eor_mi_r13_r8_r3_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r6_r12_r1_LSR_12),
    kInstruction_eor_eq_r6_r12_r1_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r10_r11_r4_LSR_27),
    kInstruction_eor_le_r10_r11_r4_LSR_27,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r7_r0_r1_ASR_15),
    kInstruction_eor_le_r7_r0_r1_ASR_15,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r12_r0_r10_ASR_13),
    kInstruction_eor_ne_r12_r0_r10_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r1_r11_r12_ASR_1),
    kInstruction_eor_hi_r1_r11_r12_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r2_r12_r10_ASR_28),
    kInstruction_eor_cs_r2_r12_r10_ASR_28,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r0_r7_r14_LSR_4),
    kInstruction_eor_vc_r0_r7_r14_LSR_4,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r9_r8_r6_LSR_6),
    kInstruction_eor_gt_r9_r8_r6_LSR_6,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r9_r8_r11_ASR_5),
    kInstruction_eor_cc_r9_r8_r11_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r0_r12_r4_ASR_22),
    kInstruction_eor_le_r0_r12_r4_ASR_22,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r6_r4_r14_ASR_2),
    kInstruction_eor_vs_r6_r4_r14_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r1_r13_r12_ASR_14),
    kInstruction_eor_le_r1_r13_r12_ASR_14,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r0_r3_r3_LSR_6),
    kInstruction_eor_le_r0_r3_r3_LSR_6,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r2_r7_r3_ASR_23),
    kInstruction_eor_ls_r2_r7_r3_ASR_23,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r12_r3_r11_LSR_13),
    kInstruction_eor_ge_r12_r3_r11_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r3_r0_r9_LSR_16),
    kInstruction_eor_ne_r3_r0_r9_LSR_16,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r5_r14_r10_ASR_24),
    kInstruction_eor_ge_r5_r14_r10_ASR_24,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r14_r4_r1_ASR_16),
    kInstruction_eor_eq_r14_r4_r1_ASR_16,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r5_r1_r9_ASR_17),
    kInstruction_eor_cs_r5_r1_r9_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r4_r7_r2_LSR_17),
    kInstruction_eor_mi_r4_r7_r2_LSR_17,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r9_r0_r7_LSR_18),
    kInstruction_eor_ne_r9_r0_r7_LSR_18,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r5_r2_r13_LSR_12),
    kInstruction_eor_al_r5_r2_r13_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r12_r13_r1_LSR_28),
    kInstruction_eor_pl_r12_r13_r1_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r9_r7_r4_ASR_7),
    kInstruction_eor_vc_r9_r7_r4_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r4_r11_r9_ASR_5),
    kInstruction_eor_le_r4_r11_r9_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r1_r14_r3_ASR_26),
    kInstruction_eor_cc_r1_r14_r3_ASR_26,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r1_r2_r1_LSR_27),
    kInstruction_eor_le_r1_r2_r1_LSR_27,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r14_r0_r5_LSR_11),
    kInstruction_eor_ge_r14_r0_r5_LSR_11,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r5_r5_r0_ASR_19),
    kInstruction_eor_cc_r5_r5_r0_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r11_r11_r6_LSR_4),
    kInstruction_eor_ne_r11_r11_r6_LSR_4,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r13_r10_r9_LSR_18),
    kInstruction_eor_vc_r13_r10_r9_LSR_18,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r10_r10_r7_ASR_26),
    kInstruction_eor_hi_r10_r10_r7_ASR_26,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r2_r8_r12_ASR_21),
    kInstruction_eor_al_r2_r8_r12_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r5_r4_r6_LSR_5),
    kInstruction_eor_vc_r5_r4_r6_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r0_r9_r7_LSR_24),
    kInstruction_eor_cc_r0_r9_r7_LSR_24,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r10_r9_r3_LSR_32),
    kInstruction_eor_ls_r10_r9_r3_LSR_32,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r8_r12_r7_ASR_14),
    kInstruction_eor_vc_r8_r12_r7_ASR_14,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r6_r13_r8_ASR_15),
    kInstruction_eor_le_r6_r13_r8_ASR_15,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r0_r0_r13_ASR_9),
    kInstruction_eor_le_r0_r0_r13_ASR_9,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r9_r3_r0_ASR_5),
    kInstruction_eor_eq_r9_r3_r0_ASR_5,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r0_r7_r5_LSR_21),
    kInstruction_eor_mi_r0_r7_r5_LSR_21,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r13_r1_r8_LSR_19),
    kInstruction_eor_mi_r13_r1_r8_LSR_19,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r7_r0_r7_ASR_26),
    kInstruction_eor_le_r7_r0_r7_ASR_26,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r7_r4_r3_ASR_20),
    kInstruction_eor_mi_r7_r4_r3_ASR_20,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r3_r5_r8_ASR_23),
    kInstruction_eor_al_r3_r5_r8_ASR_23,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r4_r12_r5_LSR_28),
    kInstruction_eor_ge_r4_r12_r5_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r7_r13_r13_ASR_1),
    kInstruction_eor_vs_r7_r13_r13_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r8_r8_r11_LSR_23),
    kInstruction_eor_gt_r8_r8_r11_LSR_23,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r13_r8_r4_ASR_7),
    kInstruction_eor_eq_r13_r8_r4_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r14_r3_r13_LSR_12),
    kInstruction_eor_eq_r14_r3_r13_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r5_r13_r10_ASR_21),
    kInstruction_eor_vs_r5_r13_r10_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r4_r2_r8_ASR_31),
    kInstruction_eor_vc_r4_r2_r8_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r2_r9_r12_ASR_18),
    kInstruction_eor_vc_r2_r9_r12_ASR_18,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r4_r8_r11_ASR_3),
    kInstruction_eor_pl_r4_r8_r11_ASR_3,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r11_r8_r1_ASR_13),
    kInstruction_eor_cc_r11_r8_r1_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r11_r13_r2_ASR_11),
    kInstruction_eor_pl_r11_r13_r2_ASR_11,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r8_r5_r5_LSR_9),
    kInstruction_eor_ge_r8_r5_r5_LSR_9,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r2_r6_r7_LSR_22),
    kInstruction_eor_mi_r2_r6_r7_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r0_r1_r1_LSR_27),
    kInstruction_eor_cs_r0_r1_r1_LSR_27,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r2_r0_r5_ASR_22),
    kInstruction_eor_vs_r2_r0_r5_ASR_22,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r13_r1_r3_ASR_10),
    kInstruction_eor_cs_r13_r1_r3_ASR_10,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r5_r6_r8_LSR_24),
    kInstruction_eor_vs_r5_r6_r8_LSR_24,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r5_r2_r10_LSR_15),
    kInstruction_eor_ge_r5_r2_r10_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r8_r10_r10_ASR_26),
    kInstruction_eor_hi_r8_r10_r10_ASR_26,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r7_r6_r11_LSR_19),
    kInstruction_eor_vc_r7_r6_r11_LSR_19,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r7_r5_r0_LSR_1),
    kInstruction_eor_ls_r7_r5_r0_LSR_1,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r9_r4_r12_LSR_28),
    kInstruction_eor_al_r9_r4_r12_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r2_r2_r5_ASR_19),
    kInstruction_eor_vs_r2_r2_r5_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r9_r12_r11_LSR_26),
    kInstruction_eor_mi_r9_r12_r11_LSR_26,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r13_r7_r8_LSR_6),
    kInstruction_eor_ne_r13_r7_r8_LSR_6,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r13_r7_r0_LSR_20),
    kInstruction_eor_al_r13_r7_r0_LSR_20,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r5_r5_r4_ASR_9),
    kInstruction_eor_eq_r5_r5_r4_ASR_9,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r7_r11_r10_ASR_16),
    kInstruction_eor_le_r7_r11_r10_ASR_16,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r14_r14_r13_LSR_3),
    kInstruction_eor_lt_r14_r14_r13_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r5_r9_r2_ASR_7),
    kInstruction_eor_pl_r5_r9_r2_ASR_7,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r2_r13_r14_LSR_13),
    kInstruction_eor_cc_r2_r13_r14_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r2_r8_r11_ASR_11),
    kInstruction_eor_gt_r2_r8_r11_ASR_11,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r8_r12_r8_ASR_1),
    kInstruction_eor_hi_r8_r12_r8_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r11_r12_r12_LSR_26),
    kInstruction_eor_cc_r11_r12_r12_LSR_26,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r6_r4_r1_ASR_27),
    kInstruction_eor_eq_r6_r4_r1_ASR_27,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r7_r6_r7_ASR_17),
    kInstruction_eor_eq_r7_r6_r7_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r10_r12_r0_LSR_3),
    kInstruction_eor_mi_r10_r12_r0_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r2_r1_r5_ASR_20),
    kInstruction_eor_ge_r2_r1_r5_ASR_20,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r12_r12_r3_ASR_25),
    kInstruction_eor_lt_r12_r12_r3_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r11_r7_r8_ASR_13),
    kInstruction_eor_mi_r11_r7_r8_ASR_13,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r5_r5_r13_ASR_4),
    kInstruction_eor_al_r5_r5_r13_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r8_r9_r4_LSR_5),
    kInstruction_eor_eq_r8_r9_r4_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r9_r5_r0_LSR_5),
    kInstruction_eor_ne_r9_r5_r0_LSR_5,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r4_r7_r7_ASR_22),
    kInstruction_eor_hi_r4_r7_r7_ASR_22,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r13_r12_r14_ASR_26),
    kInstruction_eor_al_r13_r12_r14_ASR_26,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r11_r6_r1_ASR_11),
    kInstruction_eor_lt_r11_r6_r1_ASR_11,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r4_r2_r11_LSR_27),
    kInstruction_eor_cs_r4_r2_r11_LSR_27,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r4_r5_r12_LSR_22),
    kInstruction_eor_cc_r4_r5_r12_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r6_r1_r1_LSR_23),
    kInstruction_eor_mi_r6_r1_r1_LSR_23,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r7_r1_r2_LSR_30),
    kInstruction_eor_eq_r7_r1_r2_LSR_30,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r2_r13_r12_ASR_6),
    kInstruction_eor_al_r2_r13_r12_ASR_6,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r9_r13_r10_ASR_19),
    kInstruction_eor_ge_r9_r13_r10_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r1_r10_r9_LSR_3),
    kInstruction_eor_le_r1_r10_r9_LSR_3,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r3_r11_r9_LSR_18),
    kInstruction_eor_le_r3_r11_r9_LSR_18,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r1_r7_r13_LSR_23),
    kInstruction_eor_vs_r1_r7_r13_LSR_23,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r14_r9_r4_ASR_2),
    kInstruction_eor_cc_r14_r9_r4_ASR_2,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r1_r14_r2_ASR_15),
    kInstruction_eor_mi_r1_r14_r2_ASR_15,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ne_r8_r1_r14_ASR_32),
    kInstruction_eor_ne_r8_r1_r14_ASR_32,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r14_r12_r14_LSR_21),
    kInstruction_eor_hi_r14_r12_r14_LSR_21,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r6_r2_r0_LSR_1),
    kInstruction_eor_lt_r6_r2_r0_LSR_1,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r5_r12_r4_ASR_4),
    kInstruction_eor_ls_r5_r12_r4_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r3_r12_r8_ASR_25),
    kInstruction_eor_vs_r3_r12_r8_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r11_r6_r11_LSR_11),
    kInstruction_eor_hi_r11_r6_r11_LSR_11,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r5_r7_r11_LSR_13),
    kInstruction_eor_vc_r5_r7_r11_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r13_r9_r9_LSR_21),
    kInstruction_eor_cc_r13_r9_r9_LSR_21,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r3_r14_r14_ASR_31),
    kInstruction_eor_al_r3_r14_r14_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r13_r3_r9_LSR_28),
    kInstruction_eor_ls_r13_r3_r9_LSR_28,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r11_r5_r11_ASR_26),
    kInstruction_eor_pl_r11_r5_r11_ASR_26,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r2_r9_r8_ASR_25),
    kInstruction_eor_cc_r2_r9_r8_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r10_r2_r6_ASR_8),
    kInstruction_eor_al_r10_r2_r6_ASR_8,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vc_r12_r9_r2_ASR_15),
    kInstruction_eor_vc_r12_r9_r2_ASR_15,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r7_r9_r8_LSR_13),
    kInstruction_eor_vs_r7_r9_r8_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r12_r6_r7_ASR_21),
    kInstruction_eor_pl_r12_r6_r7_ASR_21,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r0_r0_r11_ASR_10),
    kInstruction_eor_eq_r0_r0_r11_ASR_10,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r1_r12_r9_LSR_8),
    kInstruction_eor_lt_r1_r12_r9_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r14_r14_r8_LSR_4),
    kInstruction_eor_hi_r14_r14_r8_LSR_4,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r10_r12_r14_LSR_14),
    kInstruction_eor_vs_r10_r12_r14_LSR_14,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r11_r4_r8_ASR_4),
    kInstruction_eor_lt_r11_r4_r8_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r13_r14_r14_LSR_8),
    kInstruction_eor_hi_r13_r14_r14_LSR_8,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r0_r7_r8_ASR_8),
    kInstruction_eor_al_r0_r7_r8_ASR_8,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cc_r12_r14_r1_ASR_25),
    kInstruction_eor_cc_r12_r14_r1_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r12_r0_r2_LSR_4),
    kInstruction_eor_pl_r12_r0_r2_LSR_4,
  },
  {
    ARRAY_SIZE(kInstruction_eor_pl_r12_r2_r2_LSR_15),
    kInstruction_eor_pl_r12_r2_r2_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r11_r12_r3_LSR_13),
    kInstruction_eor_gt_r11_r12_r3_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r2_r7_r6_ASR_19),
    kInstruction_eor_al_r2_r7_r6_ASR_19,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r0_r3_r5_LSR_11),
    kInstruction_eor_eq_r0_r3_r5_LSR_11,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r1_r12_r1_LSR_25),
    kInstruction_eor_mi_r1_r12_r1_LSR_25,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r2_r7_r2_LSR_20),
    kInstruction_eor_hi_r2_r7_r2_LSR_20,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r14_r12_r2_LSR_2),
    kInstruction_eor_gt_r14_r12_r2_LSR_2,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r1_r13_r4_LSR_15),
    kInstruction_eor_gt_r1_r13_r4_LSR_15,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r11_r4_r12_ASR_11),
    kInstruction_eor_lt_r11_r4_r12_ASR_11,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r0_r0_r14_LSR_26),
    kInstruction_eor_cs_r0_r0_r14_LSR_26,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r12_r6_r0_LSR_22),
    kInstruction_eor_lt_r12_r6_r0_LSR_22,
  },
  {
    ARRAY_SIZE(kInstruction_eor_al_r11_r8_r2_ASR_9),
    kInstruction_eor_al_r11_r8_r2_ASR_9,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ls_r8_r10_r3_ASR_17),
    kInstruction_eor_ls_r8_r10_r3_ASR_17,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r7_r2_r14_LSR_13),
    kInstruction_eor_hi_r7_r2_r14_LSR_13,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r13_r10_r12_ASR_31),
    kInstruction_eor_hi_r13_r10_r12_ASR_31,
  },
  {
    ARRAY_SIZE(kInstruction_eor_cs_r1_r5_r10_ASR_29),
    kInstruction_eor_cs_r1_r5_r10_ASR_29,
  },
  {
    ARRAY_SIZE(kInstruction_eor_lt_r11_r11_r9_LSR_18),
    kInstruction_eor_lt_r11_r11_r9_LSR_18,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r3_r4_r4_LSR_1),
    kInstruction_eor_gt_r3_r4_r4_LSR_1,
  },
  {
    ARRAY_SIZE(kInstruction_eor_ge_r10_r12_r4_LSR_12),
    kInstruction_eor_ge_r10_r12_r4_LSR_12,
  },
  {
    ARRAY_SIZE(kInstruction_eor_hi_r4_r13_r11_ASR_25),
    kInstruction_eor_hi_r4_r13_r11_ASR_25,
  },
  {
    ARRAY_SIZE(kInstruction_eor_le_r0_r8_r4_ASR_4),
    kInstruction_eor_le_r0_r8_r4_ASR_4,
  },
  {
    ARRAY_SIZE(kInstruction_eor_mi_r14_r14_r3_LSR_31),
    kInstruction_eor_mi_r14_r14_r3_LSR_31,
  },
  {
    ARRAY_SIZE(kInstruction_eor_gt_r7_r4_r8_ASR_15),
    kInstruction_eor_gt_r7_r4_r8_ASR_15,
  },
  {
    ARRAY_SIZE(kInstruction_eor_eq_r4_r6_r6_ASR_1),
    kInstruction_eor_eq_r4_r6_r6_ASR_1,
  },
  {
    ARRAY_SIZE(kInstruction_eor_vs_r13_r2_r6_ASR_30),
    kInstruction_eor_vs_r13_r2_r6_ASR_30,
  },
};

#endif  // VIXL_ASSEMBLER_COND_RD_RN_OPERAND_RM_SHIFT_AMOUNT_1TO32_EOR_A32_H_
